#!/usr/bin/python

from math import *
import numpy as np
import Manyo as m
#import PeakFit as Adv
import Adv
import time

####    linear combination of gaussian    ####
def dist(x, param):
    sum=param[0]
    for i in range(len(param[1])):
        a, c, w = param[1][i]
        sum = sum + a*exp(-1.0*((x-c)/w)**2)
    return sum

####    sign function    ####
def sign(r):
    if r > 0.0:
        s = 1.0
    elif r == 0.0:
        s = 0.0
    else:
        s = -1.0
    return s

####    initialize an ElementContainer    ####
def initElementContainer(xmin, xmax, nDiv, param):

    bin = m.MakeDoubleVector(nDiv+1)
    delta = (xmax - xmin)/nDiv
    for i in range(nDiv+1):
        bin[i] = xmin + delta*i

    y = m.MakeDoubleVector(nDiv)
    e = m.MakeDoubleVector(nDiv)
    for i in range(nDiv):
        xc = (bin[i] + bin[i+1])/2.0

        p = dist(xc, param) # orijinal
        ####    no noize    ####
        y[i] = p
        #e[i] = param[0]/3.0
        e[i] = 1.0
        ####    uniform background noize    ####
        #q = sign(np.random.rand(1)-0.5)*(param[0]/3.0)*sqrt(-1.0*log(np.random.rand(1))) # uniform back graund noize
        #y[i] = p + q
        #e[i] = param[0]/3.0
        ####    noize proprtianl to original data
        #q = sign(np.random.rand(1)-0.5)*(p/10.0)*sqrt(-1.0*log(np.random.rand(1)))        # noise that is proportinal to the original
        #y[i] = p + q
        #e[i] = p/10.0

    ec = m.ElementContainer()
    ec.AddToHeader("run number", 1)
    ec.AddToHeader("level",      1)
    ec.AddToHeader("Inst.",      "manyo")
    ec.Add("TOF",       bin, "sec." )
    ec.Add("Intensity", y,   "count")
    ec.Add("Error",     e,   "count")
    ec.SetKeys("TOF", "Intensity", "Error")

    return ec

def outputElementContainer(ec):
    bin = ec.Put(ec.PutXKey())
    y   = ec.Put(ec.PutYKey())
    e   = ec.Put(ec.PutEKey())

    print str("No.").rjust(4), str("----------- bin -----------").rjust(27), str("xc").rjust(10), str("Intensity").rjust(23), str("error").rjust(23)
    for i in range(ec.PutSize(ec.PutYKey())):
         print str(i).rjust(4), "[", str(bin[i]).rjust(10), ",", str(bin[i+1]).rjust(10), ")", str((bin[i]+bin[i+1])/2.0).rjust(10), str(y[i]).rjust(23), str(e[i]).rjust(23)

####    plot    ####
def plotPeakData(src, smoothed, peakData):
    srcBin=src.Put(src.PutXKey())

    g=m.GnuplotInterface()

    g.e("set xlabel '" + src.PutXKey() + " / " + src.PutUnit(src.PutXKey()) + "'")
    g.e("set xrange[" + str(srcBin.front()) + ":" +str(srcBin.back())+"]")

    g.e("set ylabel '" + src.PutYKey() + " / " + src.PutUnit(src.PutYKey()) + "'")
    g.e("set autoscale y")

    v=peakData.toVector()
    for i in range(peakData.size()):
        peak=peakData.getPeak(i)
        v=peak.toFullVector()
        h=v[0] # height
        c=v[1] # position
        l=v[3] # left  pos at HWHM
        u=v[4] # right pos at HWHM
        #print "peak id = ", i, p
        g.e("set arrow "+str(3*i+1)+" from "+str(c)+", 0 to "+str(c)+", 150000 nohead\n")  # guide line for a peak or a sholder
        g.e("set label "+str(4*i+1)+" '"+str(c)+"' at "+str(c)+",10000" )                  # the position of a peak or a sholder
        g.e("set label "+str(4*i+2)+" '"+str(h)+"' at "+str(c)+","+str(h)+" front" )       # the height   of a peak or a sholder
        if c-l > 0.0:
            g.e("set arrow "+str(3*i+2)+" from "+str(c)+","+str(h/2.0)+" to "+str(l)+","+str(h/2.0)) # guide line for the lower bound at hwhm
            g.e("set label "+str(4*i+3)+" '"+str(c-l)+"' at "+str((c+l)/2.0)+","+str(h/2.0)+" center front" )  # the width
        if u-c > 0.0:
            g.e("set arrow "+str(3*i+3)+" from "+str(c)+","+str(h/2.0)+" to "+str(u)+","+str(h/2.0)) # guide line  for the upper bound at hwhm
            g.e("set label "+str(4*i+4)+" '"+str(u-c)+"' at "+str((c+u)/2.0)+","+str(h/2.0)+" center front" )  # the width

    while 1:
        g.e("plot '-' using 1:2 with lines linewidth 1 title 'source', '-' using 1:3 with lines linewidth 1 title 'smoothed'")

        for i in range(src.PutSize(src.PutYKey())):
            g.e( str( (srcBin[i]+srcBin[i+1])/2.0 ) + " " + str( src.Put(src.PutYKey(), i) )+ " " + str( smoothed.Put(smoothed.PutYKey(), i) ) )
        g.e("e")

        c=raw_input("plotPeakData: hit any key except return for next\n")
        if c != "":
            break
    #g.e("pause -1 'hit any key'")

    del g
    del srcBin


def plotNorm(method):
    ic = method.getConvergenceHistoryForInt4(  Adv.NewLevmar.ITERATION_COUNT  )
    rf = method.getConvergenceHistoryForDouble(Adv.NewLevmar.R_FACTOR         )
    rn = method.getConvergenceHistoryForDouble(Adv.NewLevmar.RESIDUAL_ERR_NORM)
    gn = method.getConvergenceHistoryForDouble(Adv.NewLevmar.GRADIENT_NORM    )
    pn = method.getConvergenceHistoryForDouble(Adv.NewLevmar.PARAM_DIFF_NORM  )
    t  = method.getConvergenceHistoryForInt4(  Adv.NewLevmar.ITERATION_TIME    )

    g=m.GnuplotInterface()

    g.e("set xlabel 'iteration'")
    if ic.size() == 1:
        cmd="set xrange [-0.5:0.5]"
    else:
        cmd="set xrange ["+repr(ic.front())+":"+repr(ic.back())+"]"
    g.e(cmd)

    g.e("set ylabel 'norm'")
    g.e("set autoscale y")
    g.e("set logscale y 10.0")

    cmd =  "plot"
    cmd = cmd + " '-' using 1:2 with linespoints title '" + Adv.NewLevmar.R_FACTOR + "'"
    #cmd = cmd + ","
    #cmd = cmd + " '-' using 1:3 with linespoints title '" + Adv.NewLevmar.RESIDUAL?ERR_NORM + "'"
    #cmd = cmd + ","
    #cmd = cmd + " '-' using 1:4 with linespoints title '" + Adv.NewLevmar.GRADIENT_NORM + "'"
    #cmd = cmd + ","
    #cmd = cmd + " '-' using 1:5 with linespoints title '" + Adv.NewLevmar.PARAM_DIFF_NORM + "'"
    g.e(cmd)

    for i in range(ic.size()):
        data =              str(ic[i]/1.0).rjust(5)
        data = data + " " + str(rf[i]    ).rjust(23)
        data = data + " " + str(rn[i]    ).rjust(23)
        data = data + " " + str(gn[i]    ).rjust(23)
        if pn[i] != 0.0:
            data = data + " " + str(pn[i]    ).rjust(23)
        else:
            data = data + " " + "                       "
        g.e(data)
        #print data
    g.e("e")

    g.e("pause " + str(t.back()/1000000))

    del g
    del ic
    del rf
    del rn
    del gn
    del pn
    del t


def plotAll(src, smoothed, fittied, components):
    xkey=src.PutXKey()
    ykey=src.PutYKey()
    srcBin      = src.Put(xkey)

    g=m.GnuplotInterface()

    g.e("set xlabel '" + xkey + " / " + src.PutUnit(xkey) + "'")
    g.e("set xrange[" + str(srcBin.front()) + ":" +str(srcBin.back())+"]")

    g.e("set ylabel '" + ykey + " / " + src.PutUnit(ykey) + "'")
    g.e("set autoscale y")

    arrowCount=1
    labelCount=1
    for j in range(components.PutSize()):
        func=components.Put(j).PutHeader().PutString(Adv.NewLevmar.FUNCTIONS)
        v=components.Put(j).PutHeader().PutDoubleVector(Adv.NewLevmar.PARAMETER_VALUES)
        if func == "gaussian":
            h=v[0]
            c=v[1]
            w=v[2]
            # position and height of a component
            g.e("set arrow "+str(arrowCount)+" from "+str(c)+", 0 to "+str(c)+","+ str(h) + " front") # guide line for a peak or a sholder
            arrowCount=arrowCount+1
            g.e("set label "+str(labelCount)+" '"+str(c)+"' at "+str(c)+",0.0 front" )                # the position of a peak or a sholder
            labelCount=labelCount+1
            g.e("set label "+str(labelCount)+" '"+str(h)+"' at "+str(c)+","+str(h)+" front" )         # the height   of a peak or a sholder
            labelCount=labelCount+1
            # width of a component
            g.e("set arrow "+str(arrowCount)+" from "+str(c)+","+str(h/2.0)+" to "+str(c-w)+","+str(h/2.0)) # guide line for the lower bound at hwhm
            arrowCount=arrowCount+1
            g.e("set label "+str(labelCount)+" '"+str(w)+"' at "+str((c+(c-w))/2.0)+","+str(h/2.0)+" center front" )  # the width
            labelCount=labelCount+1
        if func == "constant":
            h=v[0]
            g.e("set label "+str(labelCount)+" '"+str(w)+"' at "+str((c+(c-w))/2.0)+","+str(h/2.0)+" center front" )  # the width
            labelCount=labelCount+1

    while 1:
        cmd = "plot"
        cmd = cmd + " '-' using 1:2 with lines linewidth 1 title 'original'"
        cmd = cmd + ", '-' using 1:3 with lines linewidth 1 title 'smoothed'"
        cmd = cmd + ", '-' using 1:4 with lines linewidth 1 title 'fittied'"
        for j in range(components.PutSize()):
            cmd = cmd + ", '-' using 1:"+str(5+j)+" with lines linewidth 1 title 'func "+str(j)+"'"
        g.e(cmd)

        for i in range(src.PutSize(ykey)):
            data = str( (srcBin[i]+srcBin[i+1])/2.0                ).rjust(7)
            data = data + " " + str( src.Put(ykey, i)              ).rjust(10)
            data = data + " " + str( smoothed.Put(ykey, i)         ).rjust(10)
            data = data + " " + str( fittied.Put(ykey, i)          ).rjust(10)
            for j in range(components.PutSize()):
                data = data + " " + str( components.Put(j).Put(ykey, i)).rjust(10)
            g.e(data)
        g.e("e")

        #g.e("replot")
        c=raw_input("plotAll: hit any key except return\n")
        if c != "":
            break

    del g
    del srcBin


############            main routine            ############
########        initialise an element conatainer        ####
xmin = 0.0
xmax = 15.0
nDiv = 1500
#      background  param for f0          param for f1           param for f2
param=[     0.0,    [[35000.0, 2.8, 1.0], [100000.0, 10.0, 1.5], [100000.0, 5.0, 1.5]]]
#param=[ 1000.0,    [[35000.0, 2.8, 1.0], [100000.0, 10.0, 1.5], [100000.0, 5.0, 1.5]]]
#param=[10000.0,    [[35000.0, 2.8, 1.0], [100000.0, 10.0, 1.5], [100000.0, 5.0, 1.5]]]

src = initElementContainer(xmin, xmax, nDiv, param)
#outputElementContainer(src)

########        peak search        ########
####    create the driver for peak search    ####
peakSearch = Adv.PeakSearch(src, Adv.BSPLINE)
####    initialise parameters for smoothing    ####
peakSearch.setParam(Adv.BSpline.NUMBER_OF_BREAK_POINTS, 16)

#peakSearch = Adv.PeakSearch(src, Adv.MOVING_AVERAGE)
#peakSearch.setParam(Adv.MovingAverage.WINDOW_WIDTH, 131)
#peakSearch.setParam(Adv.MovingAverage.WINDOW_UPPER, 65)
####    peak search    ####
if peakSearch.checkParam() :              # check the consistency between source data and parameters
    peakSearch.execute()                  # execute peak search

    smoothed = peakSearch.getResult()     # get smoothed data
    peakData = peakSearch.getPeaks()      # get peaks and sholders
    #peakData.Dump()                       # print peal data
    plotPeakData(src, smoothed, peakData) # plot peak data

########        peak fit        ########
####    create dirver for peak fitting    ####
peakFit = Adv.PeakFit(src, Adv.NEW_LEVMAR)  # the fitting method is NewLevmar that supports multi-thread

####    initialise Levmar (set parameter values)    ####
# print template for Levmar parameters
paramSet=peakFit.getParam()
#paramSet.dump()

####    set domain    ####
lower=xmin
upper=xmax
c=input("lower of domain ?\n")
if c != "":
    lower=c
c=input("upper of domain ?\n")
if c != "":
    c=upper
peakFit.setDomain(lower, upper)


# difine Levmar mode
peakFit.setParam(Adv.NewLevmar.CONSTRAIN,          Adv.NewLevmar.NO_CONSTRAIN)
peakFit.setParam(Adv.NewLevmar.USE_NUMERICAL_DIFF, False)
peakFit.setParam(Adv.NewLevmar.DIFF_METHOD,        Adv.NewLevmar.FORWARD)
peakFit.setParam(Adv.NewLevmar.USE_DATA_WEIGHTS,   True)
peakFit.setParam(Adv.NewLevmar.MAX_ITERATIONS,     1000)
peakFit.setParam(Adv.NewLevmar.OUTPUT_INTERVAL,    50)

# fitting functions
#l=peakFit.getLowerBoun()
#u=peakFit.getUpperBoun()
expr=""
#for i in range(1, 4):
for i in range(peakData.size()):
    #c= peakData.getPeak(i).getPosition()
    #if l <= c && c <= u:
    expr = expr + " g"
#expr = expr + " c"
print expr
peakFit.setParam(Adv.NewLevmar.FUNCTIONS, expr)

# initial values of fitting parameters
v=peakData.toPyList()
#del v[12:15]
#del v[0:3]
#v.append(1.0)
print peakData.size()
peakFit.setParam(Adv.NewLevmar.PARAMETER_VALUES, v)

# lower bounds of fitting parameters
lb=[ x*0.9 for x in v ]
peakFit.setParam(Adv.NewLevmar.LOWER_BOUNDS, lb)

# upper bounds of fitting parameters
ub=[ x*1.1 for x in v ]
peakFit.setParam(Adv.NewLevmar.UPPER_BOUNDS, ub)

####    do fitting    ####
if peakFit.checkParam() :  # check the consistency of source data and Levmar parameters
    peakFit.fit()              # start to fit
    while peakFit.isFitting(): # sleep while fitting
        time.sleep(1)
    peakFit.eval()             # eval the values of fitting functiosn after fitting

    fittedParam=peakFit.getFittedParam()     # get fitted parameters
    result=peakFit.getResult()               # get the values of the fitting functions
    components=peakFit.getResultComponents() # get the values of the component functions

    #fittedParam.dump()
    plotAll(src, smoothed, result, components)
    ####result.dump



#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""

"""
import Cmm
import sys

start = int(sys.argv[1])
end = int(sys.argv[2])

for run in range(start, end+1):
    DAT = Cmm.GetHistogramSAS(run, "lambda2", "0.7 7.6 0.01", "BW", "-1 -1", 0.0, False)
    EC = Cmm.GetMonHistSAS(run, 1, "lambda2", "0.7 7.6 0.01", 0, "-1 -1", 0.0, True)
    Cmm.I0LambdaCorrection(DAT, EC)
    Cmm.ConvertQSpace(DAT, "0.0 0.0 1.0")
    Iq = Cmm.SectorAverageByAngles(DAT, "BW", "0.1 15 0.01", "0.7 7.6", "0.0 0.0", "0.0 0.0")
    Iq[0].SaveTextFile("SAS%06d_BW.dat"%run, 6)




import Manyo
import Manyo.Utsusemi as mu
import Manyo.SAS as ms

import utsusemi.ana.Reduction.BaseCommands as BC
import sys
import os

DAT = None

def UBSliceBase(DAT, outfile, UBmat, vaxes, vtitles, vunits, sliceInfo):
    """UBSlice command line version
    Defines:
    UBmat = [ 0.0, 0.0, 0.0, \
              0.0, 0.0, 0.0, \
              0.0, 0.0, 0.0  ]
    vaxes = [[1.0, 0.0, 0.0], \
             [0.0, 1.0, 0.0], \
             [0.0, 0.0, 1.0] ]
    vtitles = ["H", "K", "L"]
    vunits = ["rlu", "rlu", "rlu"]
    sliceInfo = [[0.0, 1.0, "X", 0.1], \
                 [0.0, 1.0, "Y", 0.1], \
                 [0.0, 1.0, "T", 0.1]]

    @param DAT (ElementContainerMatrix) ElementContainerMatrix of data
    @param outifle (str) path to text file for output
    @param UBmat
    @param vaxes
    @param vtitles
    @param vunits
    @param sliceInfo
    @retval None
    """
    # Preparing data process
    TQ = ms.TreatQhklWithUB()
    TQ.SetTarget(DAT)

    # Projection
    if TQ.SetUBmatrix(UBmat):
        TQ.SetViewAxes( vaxes[0], vaxes[1], vaxes[2] )
        TQ.SetViewAxesLabels(vtitles[0], vtitles[1], vtitles[2], vunits[0], vunits[1], vunits[2])
        if TQ.Projection():
            pass
        else:
            msg = "ERROR: Faled projection."
            print(msg)
            raise UserWarning(msg)
    else:
        msg = "ERROR: given UBmatrix is invalid."
        print(msg)
        raise UserWarning(msg)

    # Slicing
    indSliceX = -1
    indSliceY = -1
    indSliceT = -1
    for i in range(3):
        ax_type = sliceInfo[i][2]
        if ax_type.upper() == "X":
            indSliceX = i
        elif ax_type.upper() == "Y":
            indSliceY = i
        elif ax_type.upper() == "T":
            indSliceT = i
        else:
            msg = "ERROR: given axis type in slice info is invalid ({})".format(ax_type)
            print(msg)
            raise UserWarning(msg)
    if indSliceX == -1 or indSliceY == -1 or indSliceT == -1:
        msg = "ERROR: given axis type in slice info is invalid."
        print(msg)
        raise UserWarning(msg)

    TQ.SetSliceAxes(sliceInfo[0][2], sliceInfo[1][2], sliceInfo[2][2])

    x_range = [float(sliceInfo[indSliceX][0]), float(sliceInfo[indSliceX][1]), float(sliceInfo[indSliceX][3])]
    y_range = [float(sliceInfo[indSliceY][0]), float(sliceInfo[indSliceY][1]), float(sliceInfo[indSliceY][3])]
    t_range = [float(sliceInfo[indSliceT][0]), float(sliceInfo[indSliceT][1]), float(sliceInfo[indSliceT][3])]

    sliced_dat = Manyo.ElementContainerArray()
    TQ.Slice(sliced_dat, x_range, y_range, t_range)

    # Save sliced data as text
    keys = sliced_dat.PutHeader().PutStringVector(TQ.SAS_TREATQHK_KEYS)

    xKey = keys[0]
    yKey = keys[1]

    # output the sliced data as text
    Yvect = sliced_dat(0).PutX()
    Ylist = []
    for i in range(Yvect.size() - 1):
        Ylist.append((Yvect[i] + Yvect[i + 1]) / 2.0)

    with open(outfile, "w") as fo:
        fo.write("# {}, {}, Intensity, Error \n".format(xKey, yKey))
        for i in range(sliced_dat.PutSize()):
            Xval = sliced_dat(i).PutHeader().PutDouble(xKey)
            Ilist = sliced_dat(i).PutYList()
            Elist = sliced_dat(i).PutEList()
            for j in range(len(Ilist)):
                a_line = "{:16.8f}, {:16.8f}, {:16.8f}, {:16.8f}\n".format(Xval, Ylist[j], Ilist[j], Elist[j])
                fo.write(a_line)


def UBSlice(dat, xtalparam, outfile=""):
    """UBSlice command line version

    @param dat (str or ElementContainerMatrix) "path/to/dat.mdb" or ElementContainerMatrix of data
    @param xtalparam (str) path to XtalParam
    @param outifle (str) path to text file for output
    @retval None
    """
    if isinstance(dat, str):
        if os.path.exists(dat):
            dir_name = os.path.dirname(dat)
            filename = os.path.basename(dat)
            dat = BC.LoadDataFromManyoBinary(dir_name, filename)
            if outfile == "":
                outfile = os.path.join(dir_name, filename + ".txt")
            elif os.path.dirname(outfile) == "":
                outfile = os.path.join(dir_name, outfile)
        else:
            msg = "ERROR: file not found {}".format(dat)
            print(msg)
            raise UserWarning(msg)

    elif isinstance(dat, Manyo.ElementContainerMatrix):
        pass
    else:
        msg = "ERROR: argument dat must be path/to/data.mdb or ElementContainerMatrix"
        print(msg)
        raise UserWarning(msg)

    if not os.path.exists(xtalparam):
        msg = "ERROR: argument xtalparam not found."
        print(msg)
        raise UserWarning(msg)

    # Define UB matrix
    UBmat = [ 0.0, 0.0, 0.0, \
              0.0, 0.0, 0.0, \
              0.0, 0.0, 0.0  ]
    vaxes = [[1.0, 0.0, 0.0], \
             [0.0, 1.0, 0.0], \
             [0.0, 0.0, 1.0] ]
    vtitles = ["H", "K", "L"]
    vunits = ["rlu", "rlu", "rlu"]

    sliceInfo = [[0.0, 1.0, "X", 0.1], \
                 [0.0, 1.0, "Y", 0.1], \
                 [0.0, 1.0, "T", 0.1]]

    vcp=mu.UtsusemiSqeCalcXtalParams()
    flags = vcp.TOXML_UBMATRIX + vcp.TOXML_SLICINGINFO + vcp.TOXML_PROJECTION
    if vcp.LoadFile(xtalparam, flags):
        ubmat_v = vcp.PutUBMatrix()
        qaxes_v = vcp.PutViewAxes()
        qaxes_labels_v=vcp.PutViewAxesLabels()
        qaxes_units_v=vcp.PutViewAxesUnits()

        for i in range(9):
            UBmat[i] = ubmat_v[i]

        for i in range(3):
            ax = []
            for j in range(3):
                vaxes[i][j] = float(qaxes_v[(i * 4) + j])
            vtitles[i] = qaxes_labels_v[i]
            vunits[i] = qaxes_units_v[i]

        slice_type_v = vcp.PutAxType()

        for i in range(3):
            slice_v = vcp.PutAxRange(i)
            sliceInfo[i][0] = float(slice_v[0])
            sliceInfo[i][1] = float(slice_v[1])
            sliceInfo[i][2] = str(slice_type_v[i]).upper()
            sliceInfo[i][3] = float(slice_v[2])
    else:
        msg = "ERROR: "
        print(msg)
        raise UserWarning(msg)

    UBSliceBase(dat, outfile, UBmat, vaxes, vtitles, vunits, sliceInfo)



if __name__ == '__main__':
    # Load data file
    dir_path = "nakajima/250425UBslicerCUI/"
    filename = "213620_steady_HL.mdb"

    # Load XtalParam file
    xtalparam_file = None
    #xtalparam_file = "nakajima/250425UBslicerCUI/XtalParam_CFGO_omg_29.xml"
    xtalparam_file = "test.xml"

    dat_file = os.path.join(dir_path, filename)
    UBSlice(dat_file, xtalparam_file, "./output_UBSlice.txt")

    DAT = BC.LoadDataFromManyoBinary(dir_path, filename)
    UBSlice(DAT, xtalparam_file, "output_UBSlice2.txt")



# -*- coding: utf-8 -*-

import sys
import string
import math

import Manyo.core
import ModuleTest as ModTest

ec0 = ModTest.ec0
e2 = ec0.Averaging( 2 )
e3 = ec0.Averaging( 3 )

#module.PrintElementContainer( e2 )
#module.PrintElementContainer( e3 )



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'VisContQ_Main.ui'
##
## Created by: Qt User Interface Compiler version 5.14.1
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import (QCoreApplication, QMetaObject, QObject, QPoint,
    QRect, QSize, QUrl, Qt)
from PySide2.QtGui import (QBrush, QColor, QConicalGradient, QCursor, QFont,
    QFontDatabase, QIcon, QLinearGradient, QPalette, QPainter, QPixmap,
    QRadialGradient)
from PySide2.QtWidgets import *


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        if MainWindow.objectName():
            MainWindow.setObjectName(u"MainWindow")
        MainWindow.resize(574, 683)
        self.menu_load = QAction(MainWindow)
        self.menu_load.setObjectName(u"menu_load")
        self.menu_legacy = QAction(MainWindow)
        self.menu_legacy.setObjectName(u"menu_legacy")
        self.actionSave_as = QAction(MainWindow)
        self.actionSave_as.setObjectName(u"actionSave_as")
        self.menu_load_qxqyqz_text = QAction(MainWindow)
        self.menu_load_qxqyqz_text.setObjectName(u"menu_load_qxqyqz_text")
        self.menu_setting = QAction(MainWindow)
        self.menu_setting.setObjectName(u"menu_setting")
        self.menu_exit = QAction(MainWindow)
        self.menu_exit.setObjectName(u"menu_exit")
        self.centralwidget = QWidget(MainWindow)
        self.centralwidget.setObjectName(u"centralwidget")
        self.btApply = QPushButton(self.centralwidget)
        self.btApply.setObjectName(u"btApply")
        self.btApply.setGeometry(QRect(220, 10, 211, 31))
        self.btOpperate = QPushButton(self.centralwidget)
        self.btOpperate.setObjectName(u"btOpperate")
        self.btOpperate.setGeometry(QRect(460, 10, 99, 27))
        self.tabWidget = QTabWidget(self.centralwidget)
        self.tabWidget.setObjectName(u"tabWidget")
        self.tabWidget.setGeometry(QRect(0, 50, 571, 586))
        self.splash_label = QLabel(self.centralwidget)
        self.splash_label.setObjectName(u"splash_label")
        self.splash_label.setGeometry(QRect(5, 5, 200, 40))
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QMenuBar(MainWindow)
        self.menubar.setObjectName(u"menubar")
        self.menubar.setGeometry(QRect(0, 0, 574, 25))
        self.menuFile = QMenu(self.menubar)
        self.menuFile.setObjectName(u"menuFile")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QStatusBar(MainWindow)
        self.statusbar.setObjectName(u"statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.menubar.addAction(self.menuFile.menuAction())
        self.menuFile.addAction(self.menu_load)
        self.menuFile.addAction(self.menu_legacy)
        self.menuFile.addAction(self.actionSave_as)
        self.menuFile.addAction(self.menu_load_qxqyqz_text)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.menu_setting)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.menu_exit)

        self.retranslateUi(MainWindow)

        self.tabWidget.setCurrentIndex(-1)


        QMetaObject.connectSlotsByName(MainWindow)
    # setupUi

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QCoreApplication.translate("MainWindow", u"MainWindow", None))
        self.menu_load.setText(QCoreApplication.translate("MainWindow", u"Load", None))
        self.menu_legacy.setText(QCoreApplication.translate("MainWindow", u"Load Legacy...", None))
        self.actionSave_as.setText(QCoreApplication.translate("MainWindow", u"Save as ...", None))
        self.menu_load_qxqyqz_text.setText(QCoreApplication.translate("MainWindow", u"Load QxQyQz..", None))
        self.menu_setting.setText(QCoreApplication.translate("MainWindow", u"Setting ...", None))
        self.menu_exit.setText(QCoreApplication.translate("MainWindow", u"Exit", None))
        self.btApply.setText(QCoreApplication.translate("MainWindow", u"Apply params to other Tabs", None))
        self.btOpperate.setText(QCoreApplication.translate("MainWindow", u"CalcBar", None))
        self.splash_label.setText("")
        self.menuFile.setTitle(QCoreApplication.translate("MainWindow", u"File...", None))
    # retranslateUi


################################################################################
## Form generated from reading UI file 'VisContQ_DataOperationDialog.ui'
##
## Created by: Qt User Interface Compiler version 5.14.1
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import (QCoreApplication, QMetaObject, QObject, QPoint,
    QRect, QSize, QUrl, Qt)
from PySide2.QtGui import (QBrush, QColor, QConicalGradient, QCursor, QFont,
    QFontDatabase, QIcon, QLinearGradient, QPalette, QPainter, QPixmap,
    QRadialGradient)
from PySide2.QtWidgets import *


class Ui_DataOperationDialog(object):
    def setupUi(self, DataOperationDialog):
        if DataOperationDialog.objectName():
            DataOperationDialog.setObjectName(u"DataOperationDialog")
        DataOperationDialog.resize(560, 160)
        self.groupBox = QGroupBox(DataOperationDialog)
        self.groupBox.setObjectName(u"groupBox")
        self.groupBox.setGeometry(QRect(20, 10, 521, 101))
        self.ckPr = QCheckBox(self.groupBox)
        self.ckPr.setObjectName(u"ckPr")
        self.ckPr.setGeometry(QRect(10, 30, 201, 22))
        self.cb0 = QComboBox(self.groupBox)
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.setObjectName(u"cb0")
        self.cb0.setGeometry(QRect(10, 60, 40, 26))
        self.stEQ = QLabel(self.groupBox)
        self.stEQ.setObjectName(u"stEQ")
        self.stEQ.setGeometry(QRect(60, 60, 21, 26))
        self.m1 = QLineEdit(self.groupBox)
        self.m1.setObjectName(u"m1")
        self.m1.setGeometry(QRect(80, 60, 50, 26))
        self.asta1 = QLabel(self.groupBox)
        self.asta1.setObjectName(u"asta1")
        self.asta1.setGeometry(QRect(140, 60, 21, 26))
        self.cb1 = QComboBox(self.groupBox)
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.setObjectName(u"cb1")
        self.cb1.setGeometry(QRect(160, 60, 40, 26))
        self.cbOP = QComboBox(self.groupBox)
        self.cbOP.addItem("")
        self.cbOP.addItem("")
        self.cbOP.addItem("")
        self.cbOP.setObjectName(u"cbOP")
        self.cbOP.setGeometry(QRect(220, 60, 40, 26))
        self.asta2 = QLabel(self.groupBox)
        self.asta2.setObjectName(u"asta2")
        self.asta2.setGeometry(QRect(340, 60, 21, 26))
        self.cb2 = QComboBox(self.groupBox)
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.setObjectName(u"cb2")
        self.cb2.setGeometry(QRect(360, 60, 40, 26))
        self.m2 = QLineEdit(self.groupBox)
        self.m2.setObjectName(u"m2")
        self.m2.setGeometry(QRect(280, 60, 50, 26))
        self.btCalc = QPushButton(self.groupBox)
        self.btCalc.setObjectName(u"btCalc")
        self.btCalc.setGeometry(QRect(420, 60, 91, 27))
        self.btClose = QPushButton(DataOperationDialog)
        self.btClose.setObjectName(u"btClose")
        self.btClose.setGeometry(QRect(210, 120, 99, 27))
        QWidget.setTabOrder(self.ckPr, self.cb0)
        QWidget.setTabOrder(self.cb0, self.m1)
        QWidget.setTabOrder(self.m1, self.cb1)
        QWidget.setTabOrder(self.cb1, self.cbOP)
        QWidget.setTabOrder(self.cbOP, self.m2)
        QWidget.setTabOrder(self.m2, self.cb2)
        QWidget.setTabOrder(self.cb2, self.btCalc)
        QWidget.setTabOrder(self.btCalc, self.btClose)

        self.retranslateUi(DataOperationDialog)

        QMetaObject.connectSlotsByName(DataOperationDialog)
    # setupUi

    def retranslateUi(self, DataOperationDialog):
        DataOperationDialog.setWindowTitle(QCoreApplication.translate("DataOperationDialog", u"Dialog", None))
        self.groupBox.setTitle(QCoreApplication.translate("DataOperationDialog", u"GroupBox", None))
        self.ckPr.setText(QCoreApplication.translate("DataOperationDialog", u"Calculate Slicing Dta", None))
        self.cb0.setItemText(0, QCoreApplication.translate("DataOperationDialog", u"A", None))
        self.cb0.setItemText(1, QCoreApplication.translate("DataOperationDialog", u"B", None))
        self.cb0.setItemText(2, QCoreApplication.translate("DataOperationDialog", u"C", None))
        self.cb0.setItemText(3, QCoreApplication.translate("DataOperationDialog", u"D", None))
        self.cb0.setItemText(4, QCoreApplication.translate("DataOperationDialog", u"E", None))
        self.cb0.setItemText(5, QCoreApplication.translate("DataOperationDialog", u"F", None))
        self.cb0.setItemText(6, QCoreApplication.translate("DataOperationDialog", u"G", None))
        self.cb0.setItemText(7, QCoreApplication.translate("DataOperationDialog", u"H", None))
        self.cb0.setItemText(8, QCoreApplication.translate("DataOperationDialog", u"I", None))
        self.cb0.setItemText(9, QCoreApplication.translate("DataOperationDialog", u"J", None))

        self.stEQ.setText(QCoreApplication.translate("DataOperationDialog", u"=", None))
        self.asta1.setText(QCoreApplication.translate("DataOperationDialog", u"*", None))
        self.cb1.setItemText(0, QCoreApplication.translate("DataOperationDialog", u"A", None))
        self.cb1.setItemText(1, QCoreApplication.translate("DataOperationDialog", u"B", None))
        self.cb1.setItemText(2, QCoreApplication.translate("DataOperationDialog", u"C", None))
        self.cb1.setItemText(3, QCoreApplication.translate("DataOperationDialog", u"D", None))
        self.cb1.setItemText(4, QCoreApplication.translate("DataOperationDialog", u"E", None))
        self.cb1.setItemText(5, QCoreApplication.translate("DataOperationDialog", u"F", None))
        self.cb1.setItemText(6, QCoreApplication.translate("DataOperationDialog", u"G", None))
        self.cb1.setItemText(7, QCoreApplication.translate("DataOperationDialog", u"H", None))
        self.cb1.setItemText(8, QCoreApplication.translate("DataOperationDialog", u"I", None))
        self.cb1.setItemText(9, QCoreApplication.translate("DataOperationDialog", u"J", None))

        self.cbOP.setItemText(0, QCoreApplication.translate("DataOperationDialog", u"-", None))
        self.cbOP.setItemText(1, QCoreApplication.translate("DataOperationDialog", u"+", None))
        self.cbOP.setItemText(2, "")

        self.asta2.setText(QCoreApplication.translate("DataOperationDialog", u"*", None))
        self.cb2.setItemText(0, QCoreApplication.translate("DataOperationDialog", u"A", None))
        self.cb2.setItemText(1, QCoreApplication.translate("DataOperationDialog", u"B", None))
        self.cb2.setItemText(2, QCoreApplication.translate("DataOperationDialog", u"C", None))
        self.cb2.setItemText(3, QCoreApplication.translate("DataOperationDialog", u"D", None))
        self.cb2.setItemText(4, QCoreApplication.translate("DataOperationDialog", u"E", None))
        self.cb2.setItemText(5, QCoreApplication.translate("DataOperationDialog", u"F", None))
        self.cb2.setItemText(6, QCoreApplication.translate("DataOperationDialog", u"G", None))
        self.cb2.setItemText(7, QCoreApplication.translate("DataOperationDialog", u"H", None))
        self.cb2.setItemText(8, QCoreApplication.translate("DataOperationDialog", u"I", None))
        self.cb2.setItemText(9, QCoreApplication.translate("DataOperationDialog", u"J", None))

        self.btCalc.setText(QCoreApplication.translate("DataOperationDialog", u"Calculate", None))
        self.btClose.setText(QCoreApplication.translate("DataOperationDialog", u"Close", None))
    # retranslateUi


################################################################################
## Form generated from reading UI file 'VisContQ_SettingDialog.ui'
##
## Created by: Qt User Interface Compiler version 5.14.1
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import (QCoreApplication, QMetaObject, QObject, QPoint,
    QRect, QSize, QUrl, Qt)
from PySide2.QtGui import (QBrush, QColor, QConicalGradient, QCursor, QFont,
    QFontDatabase, QIcon, QLinearGradient, QPalette, QPainter, QPixmap,
    QRadialGradient)
from PySide2.QtWidgets import *


class Ui_SettingDialog(object):
    def setupUi(self, SettingDialog):
        if SettingDialog.objectName():
            SettingDialog.setObjectName(u"SettingDialog")
        SettingDialog.resize(400, 85)
        self.groupBox = QGroupBox(SettingDialog)
        self.groupBox.setObjectName(u"groupBox")
        self.groupBox.setGeometry(QRect(0, 0, 371, 80))
        self.ckSliceAverageMode = QCheckBox(self.groupBox)
        self.ckSliceAverageMode.setObjectName(u"ckSliceAverageMode")
        self.ckSliceAverageMode.setGeometry(QRect(20, 30, 371, 22))

        self.retranslateUi(SettingDialog)

        QMetaObject.connectSlotsByName(SettingDialog)
    # setupUi

    def retranslateUi(self, SettingDialog):
        SettingDialog.setWindowTitle(QCoreApplication.translate("SettingDialog", u"Dialog", None))
        self.groupBox.setTitle(QCoreApplication.translate("SettingDialog", u"Slice", None))
        self.ckSliceAverageMode.setText(QCoreApplication.translate("SettingDialog", u"Average Mode    On : Average  / Off : Sum", None))
    # retranslateUi




from __future__ import print_function
import Manyo as mm
import Manyo.LevmarTools as ml
import math
import numpy as np

################################################################################################################

def Gaussian(param1,param2,param3,initial_bin,final_bin,delta_bin,errFact):
    """
    @param param1        (float) hight
    @param param2        (float) center
    @param param3        (float) fwhm
    @param initial_bin   (float)
    @param final_bin     (float)
    @param delta_bin     (float)
    @param errFact       (float)
    @retval ec (ElementContainer)
    """
    ybin=[]
    ebin=[]
    xbin=[]
    ibin=[]

    num_of_bin=int(math.ceil(math.fabs((initial_bin - final_bin)/delta_bin)))

    for i in range(num_of_bin):
        ibin.append(initial_bin+i*delta_bin)
    param=[]
    param.append(param1)
    param.append(param2)
    param.append(param3)

    func = ml.AdvFuncComb("g",param)

    for i in ibin:
        ybin.append(func.eval(i))
        xbin.append(i-delta_bin/2)
    xbin.append(final_bin+delta_bin/2)
    for i in range(num_of_bin):
        if (errFact<1):
            err = 0
        else:
            err = math.sqrt(ybin[i]*fact*100)/fact/100
        ebin.append(err)

    ec=mm.ElementContainer()

    ec.Add("x",xbin)
    ec.Add("y",ybin)
    ec.Add("e",ebin)

    ec.SetKeys("x","y","e")

    return ec

################################################################################################################

def Lorentzian(param1,param2,param3,initial_bin,final_bin,delta_bin,errFact):
    """
    @param param1        (float)
    @param param2        (float)
    @param param3        (float)
    @param initial_bin   (float)
    @param final_bin     (float)
    @param delta_bin     (float)
    @param errFact       (float)
    @retval ec (ElementContainer)
    """
    ybin=[]
    ebin=[]
    xbin=[]
    ibin=[]

    num_of_bin=int(math.ceil(math.fabs((initial_bin - final_bin)/delta_bin)))

    for i in range(num_of_bin):
        ibin.append(initial_bin+i*delta_bin)
    param=[]
    param.append(param1)
    param.append(param2)
    param.append(param3)

    func = ml.AdvFuncComb("l",param)

    for i in ibin:
        ybin.append(func.eval(i))
        xbin.append(i-delta_bin/2)
    fact = pow(10,math.ceil(math.fabs(math.log10(max(ybin)))))
    xbin.append(final_bin+delta_bin/2)
    for i in range(num_of_bin):
        if (errFact<1):
            err = 0
        else:
            err = math.sqrt(ybin[i]*fact*100)/fact/100
        ebin.append(err)

    ec=mm.ElementContainer()

    ec.Add("x",xbin)
    ec.Add("y",ybin)
    ec.Add("e",ebin)

    ec.SetKeys("x","y","e")

    return ec

################################################################################################################

def Function(function,param,initial_bin,final_bin,delta_bin,errFact):
    """
    @function            (string)
    @param param         (string)
    @param initial_bin   (float)
    @param final_bin     (float)
    @param delta_bin     (float)
    @param errFact       (float)
    @retval ec (ElementContainer)
    """
    ybin=[]
    ebin=[]
    xbin=[]
    ibin=[]

    num_of_bin=int(math.ceil(math.fabs((initial_bin - final_bin)/delta_bin)))

    for i in range(num_of_bin):
        ibin.append(initial_bin+i*delta_bin)


    paramString = param.split(",")

    paramFloat = []
    for i in range(len(paramString)):
        paramFloat.append(float(paramString[i]))

    func = ml.AdvFuncComb(function,paramFloat)

    for i in ibin:
        ybin.append(func.eval(i))
        ebin.append(0)
        xbin.append(i-delta_bin/2)
    xbin.append(final_bin+delta_bin/2)
    for i in range(num_of_bin):
        if (errFact<1):
            err = 0
        else:
            err = math.sqrt(ybin[i]*fact*100)/fact/100
        ebin.append(err)

    ec=mm.ElementContainer()

    ec.Add("x",xbin)
    ec.Add("y",ybin)
    ec.Add("e",ebin)

    ec.SetKeys("x","y","e")
    return ec

################################################################################################################

def NumpyHammingWindow(ec0):
    """
    @param ec0            (ElementContainer)
    @retval ec            (ElementContainer)
    """
    xbin = ec0.PutX()
    ybin = ec0.PutY()
    ebin = ec0.PutE()

    Window = np.hamming(ybin.size())

    ybin_new = []
    ebin_new = []

    for i in range(ybin.size()):
        ybin_new.append(float(ybin[i]*Window[i]))
        ebin_new.append(float(ebin[i]*Window[i]))
    ec=mm.ElementContainer()

    ec.Add("x",xbin)
    ec.Add("y",ybin_new)
    ec.Add("e",ebin_new)

    ec.SetKeys("x","y","e")

    return ec

################################################################################################################

def NumpyHanningWindow(ec0):
    """
    @param ec0            (ElementContainer)
    @retval ec            (ElementContainer)
    """
    xbin = ec0.PutX()
    ybin = ec0.PutY()
    ebin = ec0.PutE()

    Window = np.hanning(ybin.size())

    ybin_new = []
    ebin_new = []

    for i in range(ybin.size()):
        ybin_new.append(float(ybin[i]*Window[i]))
        ebin_new.append(float(ebin[i]*Window[i]))
    ec=mm.ElementContainer()

    ec.Add("x",xbin)
    ec.Add("y",ybin_new)
    ec.Add("e",ebin_new)

    ec.SetKeys("x","y","e")

    return ec

################################################################################################################

def NumpyBlackmanWindow(ec0):
    """
    @param ec0            (ElementContainer)
    @retval ec            (ElementContainer)
    """
    xbin = ec0.PutX()
    ybin = ec0.PutY()
    ebin = ec0.PutE()

    Window = np.blackman(ybin.size())

    ybin_new = []
    ebin_new = []

    for i in range(ybin.size()):
        ybin_new.append(float(ybin[i]*Window[i]))
        ebin_new.append(float(ebin[i]*Window[i]))
    ec=mm.ElementContainer()

    ec.Add("x",xbin)
    ec.Add("y",ybin_new)
    ec.Add("e",ebin_new)

    ec.SetKeys("x","y","e")

    return ec

################################################################################################################

def NumpyBartlettWindow(ec0):
    """
    @param ec0            (ElementContainer)
    @retval ec            (ElementContainer)
    """
    xbin = ec0.PutX()
    ybin = ec0.PutY()
    ebin = ec0.PutE()

    Window = np.bartlett(ybin.size())

    ybin_new = []
    ebin_new = []

    for i in range(ybin.size()):
        ybin_new.append(float(ybin[i]*Window[i]))
        ebin_new.append(float(ebin[i]*Window[i]))
    ec=mm.ElementContainer()

    ec.Add("x",xbin)
    ec.Add("y",ybin_new)
    ec.Add("e",ebin_new)

    ec.SetKeys("x","y","e")

    return ec

################################################################################################################

def RotationX(ec0,num):
    """
    @param ec0            (ElementContainer)
    @param num            (int)
    @retval ec            (ElementContainer)
    """

    xbin = ec0.PutX()
    ybin = ec0.PutY()
    ebin = ec0.PutE()

    ybin_new = []
    ebin_new = []

    ec=mm.ElementContainer()

    if (num>ybin.size() or num<1):
        print("maximum value of num is input EC-ybin-size")
    else:
        for i in range(ybin.size()):
            if (i<=ybin.size()-num-1):
                ybin_new.append(ybin[i+num])
                ebin_new.append(ebin[i+num])
            elif ((i>ybin.size()-num-1)):
                ybin_new.append(ybin[i-(ybin.size()-num)])
                ebin_new.append(ebin[i-(ybin.size()-num)])
        ec.Add("x",xbin)
        ec.Add("y",ybin_new)
        ec.Add("e",ebin_new)
        ec.SetKeys("x","y","e")

    return ec

################################################################################################################

def HalfRotationX(ec0):
    """
    @param ec0            (ElementContainer)
    @param num            (int)
    @retval ec            (ElementContainer)
    """

    num=int(math.ceil(ec0.PutY().size()*0.5))

    ec=mm.ElementContainer()
    ec=RotationX(ec0,num)

    return ec

################################################################################################################

def AddZeroUpper(ec0,number):
    """
    @param ec0            (ElementContainer)
    @param number         (int)
    @retval ec            (ElementContainer)
    """

    xbin = ec0.PutX()
    ybin = ec0.PutY()
    ebin = ec0.PutE()

    initial= xbin[0]
    final= xbin[xbin.size()-1]
    delta = xbin[1]-xbin[0]

    xbin_new = []
    ybin_new = []
    ebin_new = []

    zero = 1e-10

    for i in range(ybin.size()):
        xbin_new.append(xbin[i])
        ybin_new.append(ybin[i])
        ebin_new.append(ebin[i])
    xbin_new.append(final)

    for i in  range(number):
        xbin_new.append(final+(i+1)*delta)
        ybin_new.append(zero)
        ebin_new.append(zero)

    ec=mm.ElementContainer()

    ec.Add("x",xbin_new)
    ec.Add("y",ybin_new)
    ec.Add("e",ebin_new)

    ec.SetKeys("x","y","e")

    return ec


################################################################################################################

def AddZeroLower(ec0,number):
    """
    @param ec0            (ElementContainer)
    @param number         (int)
    @retval ec            (ElementContainer)
    """

    xbin = ec0.PutX()
    ybin = ec0.PutY()
    ebin = ec0.PutE()

    initial= xbin[0]
    final= xbin[xbin.size()-1]
    delta = xbin[1]-xbin[0]

    xbin_new = []
    ybin_new = []
    ebin_new = []

    zero = 1e-10 

    for i in range(number):
        xbin_new.append(initial+(-number+i)*delta)
        ybin_new.append(zero)
        ebin_new.append(zero)

    for i in range(ybin.size()):
        xbin_new.append(xbin[i])
        ybin_new.append(ybin[i])
        ebin_new.append(ebin[i])
    xbin_new.append(final)

    ec=mm.ElementContainer()

    ec.Add("x",xbin_new)
    ec.Add("y",ybin_new)
    ec.Add("e",ebin_new)

    ec.SetKeys("x","y","e")

    return ec

################################################################################################################

def AddZero(ec0,number):
    """
    @param ec0            (ElementContainer)
    @param number         (int)
    @retval ec            (ElementContainer)
    """

    xbin = ec0.PutX()
    ybin = ec0.PutY()
    ebin = ec0.PutE()

    initial= xbin[0]
    final= xbin[xbin.size()-1]
    delta = xbin[1]-xbin[0]

    xbin_new = []
    ybin_new = []
    ebin_new = []

#   zero = 1e-20
#    zero1 = ybin[0]
#    zero2=ybin[ybin.size()-1]

    zero1 = 0
    zero2 = 0


    for i in range(number):
        xbin_new.append(initial+(-number+i)*delta)
        ybin_new.append(zero1)
        ebin_new.append(zero1/100000)
        #ybin_new.append(zero1/(number+1)*(i+1))
        #ebin_new.append((zero1/(number+1)*(i+1))/1000)

    for i in range(ybin.size()):
        xbin_new.append(xbin[i])
        ybin_new.append(ybin[i])
        ebin_new.append(ebin[i])
    xbin_new.append(final)

    for i in  range(number):
        xbin_new.append(final+(i+1)*delta)
        ybin_new.append(zero2)
        ebin_new.append(zero2/100000)
        #ybin_new.append(-zero2/number*i+zero2)
        #ebin_new.append((-zero2/number*i+zero2)/1000)

    ec=mm.ElementContainer()

    ec.Add("x",xbin_new)
    ec.Add("y",ybin_new)
    ec.Add("e",ebin_new)

    ec.SetKeys("x","y","e")

    return ec

################################################################################################################

def AddSreiesSamaEC(ec0,number):
    """
    @param ec0            (ElementContainer)
    @param number         (int)
    @retval ec            (ElementContainer)
    """

    xbin = ec0.PutX()
    ybin = ec0.PutY()
    ebin = ec0.PutE()

    initial= xbin[0]
    final= xbin[xbin.size()-1]
    delta = xbin[1]-xbin[0]

    xbin_new = []
    ybin_new = []
    ebin_new = []

    for i in range(ybin.size()*number):
        xbin_new.append(initial+i*delta)
        ybin_new.append(ybin[i%int(ybin.size())])
        ebin_new.append(ebin[i%int(ybin.size())])
    xbin_new.append(initial+number*ybin.size()*delta)


    ec=mm.ElementContainer()

    ec.Add("x",xbin_new)
    ec.Add("y",ybin_new)
    ec.Add("e",ebin_new)

    ec.SetKeys("x","y","e")

    return ec


################################################################################################################

def ErrorValueMultiplyConstant(ec0,constant):
    """
    @param ec0            (ElementContainer)
    @param constant         (int)
    @retval ec            (ElementContainer)
    """

    xbin = ec0.PutX()
    ybin = ec0.PutY()
    ebin = ec0.PutE()

    ec=mm.ElementContainer()
    ec.Add("x",xbin)
    ec.Add("y",ybin)
    ec.Add("e",ebin*constant)

    ec.SetKeys("x","y","e")

    return ec

################################################################################################################



#!/usr/bin/python3
# -*- coding: utf-8 -*-

import utsusemi.SAS.ana.Reduction.FileBaseCommands as FBC

# reserved words for return value in this.
DAT = None
ecs = None
EC = None
ret = None
PyObj = None
Iq = None
Tr = None
ECA = None

#########################################                                
def Save1dDataToText(dat=EC, dirpath = "/home/mlfdev/users", filename="SAS104000.dat", prec=6):
    """
    Save 1d data to text file(s).
    @param dat       (ElementContainer or list of I(q)) 1d data
    @param dirpath   (string)           directory where files are saved
    @param filename  (string)           filename
    @param prec      (int)              precision
    """
    FBC.Save1dDataToText(dat, dirpath, filename, prec)

#########################################                                
def Save1dDataToSrlz(dat=EC, dirpath = "/home/mlfdev/users", filename="SAS104000.srlz"):
    """
    Save 1d data to text file(s).
    @param dat       (ElementContainer or list of I(q)) 1d data
    @param dirpath   (string)           directory where files are saved
    @param filename  (string)           filename
    """
    FBC.Save1dDataToSrlz(dat, dirpath, filename)

#########################################                                
def SaveQzToText(dat=ECA, dirpath = "/home/mlfdev/users", filename="SAS104000_Qz.dat"):
    """
    Save Qz to a text file.
    @param dat          Qz ElementContainerArray
    @param dirpath      directory where files are saved
    @param filename     filename
    @param prec         precision
    """
    FBC.SaveQzToText(dat, dirpath, filename)

#########################################                                
def SaveIqToText(dat=Iq, dirpath = "/home/mlfdev/users", filename="SAS104000_Iq.dat", prec=6):
    """
    Save I(q) to a text file.
    @param dat         I(q) data which is list of ElementContainers
    @param dirpath      directory where files are saved
    @param filename     filename
    @param prec         precision
    """
    FBC.SaveIqToText(dat, dirpath, filename, prec)

#########################################                                
def ManyoDeserializationEC(dirpath = ".", filename=""):
    """
    Deserialize an EC file by Manyo-Lib.
    @param dirpath              directory where files are saved
    @param filename             filename
    @retval EC                 ElementContainer
    """
    return FBC.ManyoDeserializationEC(dirpath, filename)

#########################################                                
def ManyoDeserializationECM(dirpath = ".", filename=""):
    """
    Deserialize an ECM file by Manyo-Lib.
    @param dirpath              directory where files are saved
    @param filename             filename
    @retval DAT                 ElementContainerMatrix
    """
    return FBC.ManyoDeserializationECM(dirpath, filename)

#########################################                                
def ManyoSerialization(dat=DAT, dirpath = "/home/mlfdev/users", filename="SAS104000.srlz"):
    """
    Serialize data by Manyo-Lib.
    @param dat                  data container
    @param dirpath              directory where files are saved
    @param filepath             filename
    """
    FBC.ManyoSerialization(dat, dirpath, filename)

#########################################
def SaveRPMTToText(dat=DAT, dirpath="./", filename="SAS000001_RPMT.txt", lambdaRange="0.7 7.5"):
    """
    Save RPMT data to text
    @param dat             ElementContainerMatrix
    @param dirpath         directory where files are saved
    @param lambdaRange
    @param filepath        file name
    """
    FBC.SaveRPMTToText(dat, dirpath, filename, lambdaRange)

#########################################
def SaveQSpaceToText(dat=DAT, dirpath="/home/mlfdev/users", filename="SAS000001_QSpace.txt", QxRange="1.0 1.2", QyRange="-0.1 0.1", QzRange="-0.4 -0.2", cutoff=0.01):
    """
    Save Q space data to text
    @param dat      (ElementContainerMatrix) Q space ECM
    @param dirpath  (string) Directory where files are saved
    @param filename (string) File name
    @param QxRange  (string) Minimum and maximum qx separated with space
    @param QyRange  (string) Minimum and maximum qy separated with space
    @param QzRange  (string) Minimum and maximum qz separated with space
    @param cutoff   (float) Cutoff value for intensity. If it is negative, it is ignored.
    """
    FBC.SaveQSpaceToText(dat, dirpath, filename, QxRange, QyRange, QzRange, cutoff)

# Dictionary for entry the name of functions
_functions = {
            "Save1dDataToText":Save1dDataToText,
            "Save1dDataToSrlz":Save1dDataToSrlz,
            "ManyoDeserializationEC":ManyoDeserializationEC,
            "ManyoDeserializationECM":ManyoDeserializationECM,
            "ManyoSerialization":ManyoSerialization,
            "SaveQzToText":SaveQzToText,
            "SaveIqToText":SaveIqToText,
            "SaveRPMTToText":SaveRPMTToText,
            "SaveQSpaceToText":SaveQSpaceToText,
            }



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'SequencerQ_LDR_Main.ui'
#
# Created: Mon Jan 15 19:09:36 2018
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!

from PySide import QtCore, QtGui

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1174, 718)
        MainWindow.setUnifiedTitleAndToolBarOnMac(False)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.SplashPanel = QtGui.QLabel(self.centralwidget)
        self.SplashPanel.setGeometry(QtCore.QRect(10, 10, 311, 50))
        self.SplashPanel.setText("")
        self.SplashPanel.setObjectName("SplashPanel")
        self.groupBox = QtGui.QGroupBox(self.centralwidget)
        self.groupBox.setGeometry(QtCore.QRect(330, 10, 261, 51))
        self.groupBox.setObjectName("groupBox")
        self.btClear = QtGui.QPushButton(self.groupBox)
        self.btClear.setGeometry(QtCore.QRect(10, 20, 51, 32))
        self.btClear.setObjectName("btClear")
        self.btOpen = QtGui.QPushButton(self.groupBox)
        self.btOpen.setGeometry(QtCore.QRect(80, 20, 32, 32))
        self.btOpen.setText("")
        self.btOpen.setObjectName("btOpen")
        self.btSaveas = QtGui.QPushButton(self.groupBox)
        self.btSaveas.setGeometry(QtCore.QRect(120, 20, 32, 32))
        self.btSaveas.setText("")
        self.btSaveas.setObjectName("btSaveas")
        self.btCCD = QtGui.QPushButton(self.groupBox)
        self.btCCD.setGeometry(QtCore.QRect(160, 20, 99, 32))
        self.btCCD.setObjectName("btCCD")
        self.groupBox_2 = QtGui.QGroupBox(self.centralwidget)
        self.groupBox_2.setGeometry(QtCore.QRect(800, 10, 371, 51))
        self.groupBox_2.setObjectName("groupBox_2")
        self.btBegin = QtGui.QPushButton(self.groupBox_2)
        self.btBegin.setGeometry(QtCore.QRect(10, 20, 60, 32))
        self.btBegin.setObjectName("btBegin")
        self.btStop = QtGui.QPushButton(self.groupBox_2)
        self.btStop.setGeometry(QtCore.QRect(80, 20, 60, 32))
        self.btStop.setObjectName("btStop")
        self.btResume = QtGui.QPushButton(self.groupBox_2)
        self.btResume.setGeometry(QtCore.QRect(150, 20, 101, 32))
        self.btResume.setObjectName("btResume")
        self.btVis = QtGui.QPushButton(self.groupBox_2)
        self.btVis.setGeometry(QtCore.QRect(280, 20, 81, 32))
        self.btVis.setObjectName("btVis")
        self.line = QtGui.QFrame(self.groupBox_2)
        self.line.setGeometry(QtCore.QRect(260, 20, 20, 31))
        self.line.setFrameShape(QtGui.QFrame.VLine)
        self.line.setFrameShadow(QtGui.QFrame.Sunken)
        self.line.setObjectName("line")
        self.tree0 = QtGui.QTreeWidget(self.centralwidget)
        self.tree0.setGeometry(QtCore.QRect(10, 259, 300, 241))
        self.tree0.setHeaderHidden(True)
        self.tree0.setObjectName("tree0")
        self.tree0.headerItem().setText(0, "1")
        self.list1 = QtGui.QTreeWidget(self.centralwidget)
        self.list1.setGeometry(QtCore.QRect(360, 259, 800, 201))
        self.list1.setObjectName("list1")
        self.list1.headerItem().setText(0, "1")
        self.st0 = QtGui.QLabel(self.centralwidget)
        self.st0.setGeometry(QtCore.QRect(380, 70, 91, 17))
        self.st0.setObjectName("st0")
        self.btAdd = QtGui.QPushButton(self.centralwidget)
        self.btAdd.setGeometry(QtCore.QRect(320, 270, 32, 32))
        self.btAdd.setText("")
        self.btAdd.setObjectName("btAdd")
        self.btRemove = QtGui.QPushButton(self.centralwidget)
        self.btRemove.setGeometry(QtCore.QRect(320, 310, 32, 32))
        self.btRemove.setText("")
        self.btRemove.setObjectName("btRemove")
        self.btCopyAdd = QtGui.QPushButton(self.centralwidget)
        self.btCopyAdd.setGeometry(QtCore.QRect(320, 390, 32, 32))
        self.btCopyAdd.setText("")
        self.btCopyAdd.setObjectName("btCopyAdd")
        self.btUp = QtGui.QPushButton(self.centralwidget)
        self.btUp.setGeometry(QtCore.QRect(320, 430, 32, 32))
        self.btUp.setText("")
        self.btUp.setObjectName("btUp")
        self.btDown = QtGui.QPushButton(self.centralwidget)
        self.btDown.setGeometry(QtCore.QRect(320, 470, 32, 32))
        self.btDown.setText("")
        self.btDown.setObjectName("btDown")
        self.stCurrentDir = QtGui.QLabel(self.centralwidget)
        self.stCurrentDir.setGeometry(QtCore.QRect(470, 70, 671, 17))
        self.stCurrentDir.setText("")
        self.stCurrentDir.setObjectName("stCurrentDir")
        self.funcdoc = QtGui.QTextBrowser(self.centralwidget)
        self.funcdoc.setGeometry(QtCore.QRect(10, 509, 341, 171))
        self.funcdoc.setObjectName("funcdoc")
        self.btSet = QtGui.QPushButton(self.centralwidget)
        self.btSet.setGeometry(QtCore.QRect(930, 470, 120, 32))
        self.btSet.setObjectName("btSet")
        self.retval = QtGui.QLineEdit(self.centralwidget)
        self.retval.setGeometry(QtCore.QRect(610, 470, 150, 32))
        self.retval.setObjectName("retval")
        self.st2 = QtGui.QLabel(self.centralwidget)
        self.st2.setGeometry(QtCore.QRect(500, 480, 101, 17))
        self.st2.setObjectName("st2")
        self.sca_Args = QtGui.QScrollArea(self.centralwidget)
        self.sca_Args.setGeometry(QtCore.QRect(360, 510, 801, 171))
        self.sca_Args.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.sca_Args.setWidgetResizable(False)
        self.sca_Args.setObjectName("sca_Args")
        self.scrollAreaWidgetContents = QtGui.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 799, 269))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.grb_Args = QtGui.QGroupBox(self.scrollAreaWidgetContents)
        self.grb_Args.setEnabled(True)
        self.grb_Args.setGeometry(QtCore.QRect(10, 0, 780, 270))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.grb_Args.sizePolicy().hasHeightForWidth())
        self.grb_Args.setSizePolicy(sizePolicy)
        self.grb_Args.setAutoFillBackground(True)
        self.grb_Args.setTitle("")
        self.grb_Args.setFlat(True)
        self.grb_Args.setCheckable(False)
        self.grb_Args.setObjectName("grb_Args")
        self.arg1 = QtGui.QLineEdit(self.grb_Args)
        self.arg1.setGeometry(QtCore.QRect(10, 30, 240, 24))
        self.arg1.setObjectName("arg1")
        self.arg2 = QtGui.QLineEdit(self.grb_Args)
        self.arg2.setGeometry(QtCore.QRect(270, 30, 240, 24))
        self.arg2.setObjectName("arg2")
        self.arg3 = QtGui.QLineEdit(self.grb_Args)
        self.arg3.setGeometry(QtCore.QRect(530, 30, 240, 24))
        self.arg3.setObjectName("arg3")
        self.arg4 = QtGui.QLineEdit(self.grb_Args)
        self.arg4.setGeometry(QtCore.QRect(10, 80, 240, 24))
        self.arg4.setObjectName("arg4")
        self.arg5 = QtGui.QLineEdit(self.grb_Args)
        self.arg5.setGeometry(QtCore.QRect(270, 80, 240, 24))
        self.arg5.setObjectName("arg5")
        self.arg6 = QtGui.QLineEdit(self.grb_Args)
        self.arg6.setGeometry(QtCore.QRect(530, 80, 240, 24))
        self.arg6.setObjectName("arg6")
        self.arg7 = QtGui.QLineEdit(self.grb_Args)
        self.arg7.setGeometry(QtCore.QRect(10, 130, 240, 24))
        self.arg7.setObjectName("arg7")
        self.arg8 = QtGui.QLineEdit(self.grb_Args)
        self.arg8.setGeometry(QtCore.QRect(270, 130, 240, 24))
        self.arg8.setObjectName("arg8")
        self.arg9 = QtGui.QLineEdit(self.grb_Args)
        self.arg9.setGeometry(QtCore.QRect(530, 130, 240, 24))
        self.arg9.setObjectName("arg9")
        self.arg10 = QtGui.QLineEdit(self.grb_Args)
        self.arg10.setGeometry(QtCore.QRect(10, 180, 240, 24))
        self.arg10.setObjectName("arg10")
        self.arg11 = QtGui.QLineEdit(self.grb_Args)
        self.arg11.setGeometry(QtCore.QRect(270, 180, 240, 24))
        self.arg11.setObjectName("arg11")
        self.arg12 = QtGui.QLineEdit(self.grb_Args)
        self.arg12.setGeometry(QtCore.QRect(530, 180, 240, 24))
        self.arg12.setObjectName("arg12")
        self.arg13 = QtGui.QLineEdit(self.grb_Args)
        self.arg13.setGeometry(QtCore.QRect(10, 230, 240, 24))
        self.arg13.setObjectName("arg13")
        self.arg14 = QtGui.QLineEdit(self.grb_Args)
        self.arg14.setGeometry(QtCore.QRect(270, 230, 240, 24))
        self.arg14.setObjectName("arg14")
        self.arg15 = QtGui.QLineEdit(self.grb_Args)
        self.arg15.setGeometry(QtCore.QRect(530, 230, 240, 24))
        self.arg15.setObjectName("arg15")
        self.argst1 = QtGui.QLabel(self.grb_Args)
        self.argst1.setGeometry(QtCore.QRect(20, 10, 231, 17))
        self.argst1.setObjectName("argst1")
        self.argst2 = QtGui.QLabel(self.grb_Args)
        self.argst2.setGeometry(QtCore.QRect(280, 10, 231, 17))
        self.argst2.setObjectName("argst2")
        self.argst3 = QtGui.QLabel(self.grb_Args)
        self.argst3.setGeometry(QtCore.QRect(540, 10, 231, 17))
        self.argst3.setObjectName("argst3")
        self.argst4 = QtGui.QLabel(self.grb_Args)
        self.argst4.setGeometry(QtCore.QRect(20, 60, 231, 17))
        self.argst4.setObjectName("argst4")
        self.argst5 = QtGui.QLabel(self.grb_Args)
        self.argst5.setGeometry(QtCore.QRect(280, 60, 231, 17))
        self.argst5.setObjectName("argst5")
        self.argst6 = QtGui.QLabel(self.grb_Args)
        self.argst6.setGeometry(QtCore.QRect(540, 60, 231, 17))
        self.argst6.setObjectName("argst6")
        self.argst7 = QtGui.QLabel(self.grb_Args)
        self.argst7.setGeometry(QtCore.QRect(20, 110, 231, 17))
        self.argst7.setObjectName("argst7")
        self.argst8 = QtGui.QLabel(self.grb_Args)
        self.argst8.setGeometry(QtCore.QRect(280, 110, 231, 17))
        self.argst8.setObjectName("argst8")
        self.argst9 = QtGui.QLabel(self.grb_Args)
        self.argst9.setGeometry(QtCore.QRect(540, 110, 231, 17))
        self.argst9.setObjectName("argst9")
        self.argst10 = QtGui.QLabel(self.grb_Args)
        self.argst10.setGeometry(QtCore.QRect(20, 160, 231, 17))
        self.argst10.setObjectName("argst10")
        self.argst11 = QtGui.QLabel(self.grb_Args)
        self.argst11.setGeometry(QtCore.QRect(280, 160, 231, 17))
        self.argst11.setObjectName("argst11")
        self.argst12 = QtGui.QLabel(self.grb_Args)
        self.argst12.setGeometry(QtCore.QRect(540, 160, 231, 17))
        self.argst12.setObjectName("argst12")
        self.argst13 = QtGui.QLabel(self.grb_Args)
        self.argst13.setGeometry(QtCore.QRect(20, 210, 231, 17))
        self.argst13.setObjectName("argst13")
        self.argst14 = QtGui.QLabel(self.grb_Args)
        self.argst14.setGeometry(QtCore.QRect(280, 210, 231, 17))
        self.argst14.setObjectName("argst14")
        self.argst15 = QtGui.QLabel(self.grb_Args)
        self.argst15.setGeometry(QtCore.QRect(540, 210, 231, 17))
        self.argst15.setObjectName("argst15")
        self.sca_Args.setWidget(self.scrollAreaWidgetContents)
        self.gbLDRbox = QtGui.QGroupBox(self.centralwidget)
        self.gbLDRbox.setGeometry(QtCore.QRect(10, 90, 1151, 161))
        self.gbLDRbox.setFlat(False)
        self.gbLDRbox.setCheckable(True)
        self.gbLDRbox.setObjectName("gbLDRbox")
        self.sca_HistInfo = QtGui.QScrollArea(self.gbLDRbox)
        self.sca_HistInfo.setGeometry(QtCore.QRect(0, 20, 811, 141))
        self.sca_HistInfo.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.sca_HistInfo.setWidgetResizable(False)
        self.sca_HistInfo.setObjectName("sca_HistInfo")
        self.scrollAreaLDR = QtGui.QWidget()
        self.scrollAreaLDR.setEnabled(False)
        self.scrollAreaLDR.setGeometry(QtCore.QRect(0, 0, 789, 250))
        self.scrollAreaLDR.setObjectName("scrollAreaLDR")
        self.label = QtGui.QLabel(self.scrollAreaLDR)
        self.label.setGeometry(QtCore.QRect(10, 10, 91, 20))
        self.label.setObjectName("label")
        self.label_2 = QtGui.QLabel(self.scrollAreaLDR)
        self.label_2.setGeometry(QtCore.QRect(250, 10, 121, 17))
        self.label_2.setObjectName("label_2")
        self.txHistInfo = QtGui.QLineEdit(self.scrollAreaLDR)
        self.txHistInfo.setGeometry(QtCore.QRect(380, 10, 391, 27))
        self.txHistInfo.setObjectName("txHistInfo")
        self.label_3 = QtGui.QLabel(self.scrollAreaLDR)
        self.label_3.setGeometry(QtCore.QRect(10, 50, 91, 17))
        self.label_3.setObjectName("label_3")
        self.txDetParam = QtGui.QLineEdit(self.scrollAreaLDR)
        self.txDetParam.setGeometry(QtCore.QRect(100, 50, 271, 27))
        self.txDetParam.setObjectName("txDetParam")
        self.label_4 = QtGui.QLabel(self.scrollAreaLDR)
        self.label_4.setGeometry(QtCore.QRect(420, 50, 91, 17))
        self.label_4.setObjectName("label_4")
        self.txDetRange = QtGui.QLineEdit(self.scrollAreaLDR)
        self.txDetRange.setGeometry(QtCore.QRect(500, 50, 271, 27))
        self.txDetRange.setObjectName("txDetRange")
        self.label_5 = QtGui.QLabel(self.scrollAreaLDR)
        self.label_5.setGeometry(QtCore.QRect(10, 90, 91, 17))
        self.label_5.setObjectName("label_5")
        self.txTimeRange = QtGui.QLineEdit(self.scrollAreaLDR)
        self.txTimeRange.setGeometry(QtCore.QRect(100, 90, 271, 27))
        self.txTimeRange.setObjectName("txTimeRange")
        self.txMaskInfo = QtGui.QLineEdit(self.scrollAreaLDR)
        self.txMaskInfo.setGeometry(QtCore.QRect(100, 130, 271, 27))
        self.txMaskInfo.setObjectName("txMaskInfo")
        self.label_6 = QtGui.QLabel(self.scrollAreaLDR)
        self.label_6.setGeometry(QtCore.QRect(10, 130, 91, 17))
        self.label_6.setObjectName("label_6")
        self.label_7 = QtGui.QLabel(self.scrollAreaLDR)
        self.label_7.setGeometry(QtCore.QRect(420, 130, 71, 17))
        self.label_7.setObjectName("label_7")
        self.txCaseInfo = QtGui.QLineEdit(self.scrollAreaLDR)
        self.txCaseInfo.setGeometry(QtCore.QRect(500, 130, 271, 27))
        self.txCaseInfo.setObjectName("txCaseInfo")
        self.label_8 = QtGui.QLabel(self.scrollAreaLDR)
        self.label_8.setGeometry(QtCore.QRect(10, 170, 91, 17))
        self.label_8.setObjectName("label_8")
        self.txBgInfo = QtGui.QLineEdit(self.scrollAreaLDR)
        self.txBgInfo.setGeometry(QtCore.QRect(100, 170, 271, 27))
        self.txBgInfo.setObjectName("txBgInfo")
        self.txTofShift = QtGui.QLineEdit(self.scrollAreaLDR)
        self.txTofShift.setGeometry(QtCore.QRect(500, 170, 271, 27))
        self.txTofShift.setObjectName("txTofShift")
        self.txAnaMode = QtGui.QLineEdit(self.scrollAreaLDR)
        self.txAnaMode.setGeometry(QtCore.QRect(100, 210, 271, 27))
        self.txAnaMode.setObjectName("txAnaMode")
        self.label_9 = QtGui.QLabel(self.scrollAreaLDR)
        self.label_9.setGeometry(QtCore.QRect(420, 170, 71, 17))
        self.label_9.setObjectName("label_9")
        self.label_10 = QtGui.QLabel(self.scrollAreaLDR)
        self.label_10.setGeometry(QtCore.QRect(10, 210, 91, 17))
        self.label_10.setObjectName("label_10")
        self.txRunNo = QtGui.QLineEdit(self.scrollAreaLDR)
        self.txRunNo.setGeometry(QtCore.QRect(100, 10, 113, 27))
        self.txRunNo.setObjectName("txRunNo")
        self.label_11 = QtGui.QLabel(self.scrollAreaLDR)
        self.label_11.setGeometry(QtCore.QRect(420, 90, 71, 17))
        self.label_11.setObjectName("label_11")
        self.txFrameInfo = QtGui.QLineEdit(self.scrollAreaLDR)
        self.txFrameInfo.setGeometry(QtCore.QRect(500, 90, 271, 27))
        self.txFrameInfo.setObjectName("txFrameInfo")
        self.sca_HistInfo.setWidget(self.scrollAreaLDR)
        self.status = QtGui.QLabel(self.gbLDRbox)
        self.status.setGeometry(QtCore.QRect(950, 140, 201, 20))
        self.status.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.status.setObjectName("status")
        self.st1 = QtGui.QLabel(self.gbLDRbox)
        self.st1.setGeometry(QtCore.QRect(830, 0, 111, 17))
        self.st1.setObjectName("st1")
        self.txRetvalLDR = QtGui.QLineEdit(self.gbLDRbox)
        self.txRetvalLDR.setGeometry(QtCore.QRect(1080, 70, 61, 27))
        self.txRetvalLDR.setObjectName("txRetvalLDR")
        self.stRetValLDR = QtGui.QLabel(self.gbLDRbox)
        self.stRetValLDR.setGeometry(QtCore.QRect(980, 70, 101, 17))
        self.stRetValLDR.setObjectName("stRetValLDR")
        self.btConnectServ = QtGui.QPushButton(self.gbLDRbox)
        self.btConnectServ.setGeometry(QtCore.QRect(840, 70, 111, 51))
        self.btConnectServ.setObjectName("btConnectServ")
        self.ckEditParams = QtGui.QCheckBox(self.gbLDRbox)
        self.ckEditParams.setGeometry(QtCore.QRect(830, 50, 121, 22))
        self.ckEditParams.setObjectName("ckEditParams")
        self.label_12 = QtGui.QLabel(self.gbLDRbox)
        self.label_12.setGeometry(QtCore.QRect(980, 100, 101, 21))
        self.label_12.setObjectName("label_12")
        self.txIntervalSec = QtGui.QLineEdit(self.gbLDRbox)
        self.txIntervalSec.setGeometry(QtCore.QRect(1080, 100, 61, 27))
        self.txIntervalSec.setObjectName("txIntervalSec")
        self.statusLDRserver = QtGui.QLabel(self.gbLDRbox)
        self.statusLDRserver.setGeometry(QtCore.QRect(870, 20, 271, 20))
        self.statusLDRserver.setObjectName("statusLDRserver")
        self.st1_2 = QtGui.QLabel(self.gbLDRbox)
        self.st1_2.setGeometry(QtCore.QRect(840, 140, 111, 17))
        self.st1_2.setObjectName("st1_2")
        self.groupBox_3 = QtGui.QGroupBox(self.centralwidget)
        self.groupBox_3.setGeometry(QtCore.QRect(610, 10, 171, 51))
        self.groupBox_3.setObjectName("groupBox_3")
        self.btLDRBegin = QtGui.QPushButton(self.groupBox_3)
        self.btLDRBegin.setGeometry(QtCore.QRect(10, 20, 60, 31))
        self.btLDRBegin.setObjectName("btLDRBegin")
        self.btLDREnd = QtGui.QPushButton(self.groupBox_3)
        self.btLDREnd.setGeometry(QtCore.QRect(90, 20, 70, 31))
        self.btLDREnd.setObjectName("btLDREnd")
        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionFile = QtGui.QAction(MainWindow)
        self.actionFile.setObjectName("actionFile")

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "MainWindow", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("MainWindow", "File", None, QtGui.QApplication.UnicodeUTF8))
        self.btClear.setText(QtGui.QApplication.translate("MainWindow", "Clear", None, QtGui.QApplication.UnicodeUTF8))
        self.btCCD.setText(QtGui.QApplication.translate("MainWindow", "Current Dir", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_2.setTitle(QtGui.QApplication.translate("MainWindow", "Control", None, QtGui.QApplication.UnicodeUTF8))
        self.btBegin.setText(QtGui.QApplication.translate("MainWindow", "Start", None, QtGui.QApplication.UnicodeUTF8))
        self.btStop.setText(QtGui.QApplication.translate("MainWindow", "Stop", None, QtGui.QApplication.UnicodeUTF8))
        self.btResume.setText(QtGui.QApplication.translate("MainWindow", "Resume", None, QtGui.QApplication.UnicodeUTF8))
        self.btVis.setText(QtGui.QApplication.translate("MainWindow", "Visualize", None, QtGui.QApplication.UnicodeUTF8))
        self.st0.setText(QtGui.QApplication.translate("MainWindow", "Current Dir :", None, QtGui.QApplication.UnicodeUTF8))
        self.btSet.setText(QtGui.QApplication.translate("MainWindow", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.st2.setText(QtGui.QApplication.translate("MainWindow", "Return Label :", None, QtGui.QApplication.UnicodeUTF8))
        self.argst1.setText(QtGui.QApplication.translate("MainWindow", "Argument1", None, QtGui.QApplication.UnicodeUTF8))
        self.argst2.setText(QtGui.QApplication.translate("MainWindow", "Argument2", None, QtGui.QApplication.UnicodeUTF8))
        self.argst3.setText(QtGui.QApplication.translate("MainWindow", "Argument3", None, QtGui.QApplication.UnicodeUTF8))
        self.argst4.setText(QtGui.QApplication.translate("MainWindow", "Argument4", None, QtGui.QApplication.UnicodeUTF8))
        self.argst5.setText(QtGui.QApplication.translate("MainWindow", "Argument5", None, QtGui.QApplication.UnicodeUTF8))
        self.argst6.setText(QtGui.QApplication.translate("MainWindow", "Argument6", None, QtGui.QApplication.UnicodeUTF8))
        self.argst7.setText(QtGui.QApplication.translate("MainWindow", "Argument7", None, QtGui.QApplication.UnicodeUTF8))
        self.argst8.setText(QtGui.QApplication.translate("MainWindow", "Argument8", None, QtGui.QApplication.UnicodeUTF8))
        self.argst9.setText(QtGui.QApplication.translate("MainWindow", "Argument9", None, QtGui.QApplication.UnicodeUTF8))
        self.argst10.setText(QtGui.QApplication.translate("MainWindow", "Argument10", None, QtGui.QApplication.UnicodeUTF8))
        self.argst11.setText(QtGui.QApplication.translate("MainWindow", "Argument11", None, QtGui.QApplication.UnicodeUTF8))
        self.argst12.setText(QtGui.QApplication.translate("MainWindow", "Argument12", None, QtGui.QApplication.UnicodeUTF8))
        self.argst13.setText(QtGui.QApplication.translate("MainWindow", "Argument13", None, QtGui.QApplication.UnicodeUTF8))
        self.argst14.setText(QtGui.QApplication.translate("MainWindow", "Argument14", None, QtGui.QApplication.UnicodeUTF8))
        self.argst15.setText(QtGui.QApplication.translate("MainWindow", "Argument15", None, QtGui.QApplication.UnicodeUTF8))
        self.gbLDRbox.setTitle(QtGui.QApplication.translate("MainWindow", "Live Data Reduction Mode", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("MainWindow", "Run Number", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("MainWindow", "Histogram param", None, QtGui.QApplication.UnicodeUTF8))
        self.txHistInfo.setText(QtGui.QApplication.translate("MainWindow", "tof,0,40000,100", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("MainWindow", "DetParam", None, QtGui.QApplication.UnicodeUTF8))
        self.txDetParam.setText(QtGui.QApplication.translate("MainWindow", "PSD", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("MainWindow", "DetRange", None, QtGui.QApplication.UnicodeUTF8))
        self.txDetRange.setText(QtGui.QApplication.translate("MainWindow", "All", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("MainWindow", "TimeRange", None, QtGui.QApplication.UnicodeUTF8))
        self.txTimeRange.setText(QtGui.QApplication.translate("MainWindow", "All", None, QtGui.QApplication.UnicodeUTF8))
        self.txMaskInfo.setText(QtGui.QApplication.translate("MainWindow", "NoFile", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("MainWindow", "MaskInfo", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("MainWindow", "CaseInfo", None, QtGui.QApplication.UnicodeUTF8))
        self.txCaseInfo.setText(QtGui.QApplication.translate("MainWindow", "None", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("MainWindow", "BGInfo", None, QtGui.QApplication.UnicodeUTF8))
        self.txBgInfo.setText(QtGui.QApplication.translate("MainWindow", "TimeDep:None", None, QtGui.QApplication.UnicodeUTF8))
        self.txTofShift.setText(QtGui.QApplication.translate("MainWindow", "None", None, QtGui.QApplication.UnicodeUTF8))
        self.txAnaMode.setText(QtGui.QApplication.translate("MainWindow", "0", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setText(QtGui.QApplication.translate("MainWindow", "TOF Shift", None, QtGui.QApplication.UnicodeUTF8))
        self.label_10.setText(QtGui.QApplication.translate("MainWindow", "AnaMode", None, QtGui.QApplication.UnicodeUTF8))
        self.txRunNo.setText(QtGui.QApplication.translate("MainWindow", "0", None, QtGui.QApplication.UnicodeUTF8))
        self.label_11.setText(QtGui.QApplication.translate("MainWindow", "FrameInfo", None, QtGui.QApplication.UnicodeUTF8))
        self.txFrameInfo.setText(QtGui.QApplication.translate("MainWindow", "None", None, QtGui.QApplication.UnicodeUTF8))
        self.status.setText(QtGui.QApplication.translate("MainWindow", "Executable", None, QtGui.QApplication.UnicodeUTF8))
        self.st1.setText(QtGui.QApplication.translate("MainWindow", "Server  Status :", None, QtGui.QApplication.UnicodeUTF8))
        self.txRetvalLDR.setText(QtGui.QApplication.translate("MainWindow", "DAT", None, QtGui.QApplication.UnicodeUTF8))
        self.stRetValLDR.setText(QtGui.QApplication.translate("MainWindow", "Return Label :", None, QtGui.QApplication.UnicodeUTF8))
        self.btConnectServ.setText(QtGui.QApplication.translate("MainWindow", "Connect Serv", None, QtGui.QApplication.UnicodeUTF8))
        self.ckEditParams.setText(QtGui.QApplication.translate("MainWindow", "Edit Params", None, QtGui.QApplication.UnicodeUTF8))
        self.label_12.setText(QtGui.QApplication.translate("MainWindow", "Interval [sec] :", None, QtGui.QApplication.UnicodeUTF8))
        self.txIntervalSec.setText(QtGui.QApplication.translate("MainWindow", "20", None, QtGui.QApplication.UnicodeUTF8))
        self.statusLDRserver.setText(QtGui.QApplication.translate("MainWindow", "Not Connected", None, QtGui.QApplication.UnicodeUTF8))
        self.st1_2.setText(QtGui.QApplication.translate("MainWindow", "Script Status :", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_3.setTitle(QtGui.QApplication.translate("MainWindow", "LiveDataReduction", None, QtGui.QApplication.UnicodeUTF8))
        self.btLDRBegin.setText(QtGui.QApplication.translate("MainWindow", "Begin", None, QtGui.QApplication.UnicodeUTF8))
        self.btLDREnd.setText(QtGui.QApplication.translate("MainWindow", "End", None, QtGui.QApplication.UnicodeUTF8))
        self.actionFile.setText(QtGui.QApplication.translate("MainWindow", "File", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'SequencerQ_Save.ui'
#
# Created: Mon Jan 15 19:09:36 2018
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(342, 170)
        self.comment = QtGui.QTextEdit(Dialog)
        self.comment.setGeometry(QtCore.QRect(10, 40, 320, 80))
        self.comment.setObjectName("comment")
        self.label = QtGui.QLabel(Dialog)
        self.label.setGeometry(QtCore.QRect(10, 10, 261, 17))
        self.label.setObjectName("label")
        self.btOk = QtGui.QPushButton(Dialog)
        self.btOk.setGeometry(QtCore.QRect(50, 130, 100, 32))
        self.btOk.setObjectName("btOk")
        self.btCancel = QtGui.QPushButton(Dialog)
        self.btCancel.setGeometry(QtCore.QRect(180, 130, 100, 32))
        self.btCancel.setObjectName("btCancel")

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        Dialog.setWindowTitle(QtGui.QApplication.translate("Dialog", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("Dialog", "Comments for the sequence :", None, QtGui.QApplication.UnicodeUTF8))
        self.btOk.setText(QtGui.QApplication.translate("Dialog", "OK", None, QtGui.QApplication.UnicodeUTF8))
        self.btCancel.setText(QtGui.QApplication.translate("Dialog", "Cancel", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'SequencerQ_Vis.ui'
#
# Created: Mon Jan 15 19:09:36 2018
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_visframe(object):
    def setupUi(self, visframe):
        visframe.setObjectName("visframe")
        visframe.resize(558, 333)
        self.centralwidget = QtGui.QWidget(visframe)
        self.centralwidget.setObjectName("centralwidget")
        self.tree = QtGui.QTreeWidget(self.centralwidget)
        self.tree.setGeometry(QtCore.QRect(10, 10, 200, 265))
        self.tree.setHeaderHidden(True)
        self.tree.setObjectName("tree")
        self.tree.headerItem().setText(0, "1")
        self.groupBox = QtGui.QGroupBox(self.centralwidget)
        self.groupBox.setGeometry(QtCore.QRect(220, 10, 221, 261))
        self.groupBox.setObjectName("groupBox")
        self.arg1 = QtGui.QLineEdit(self.groupBox)
        self.arg1.setGeometry(QtCore.QRect(110, 20, 100, 28))
        self.arg1.setObjectName("arg1")
        self.arg2 = QtGui.QLineEdit(self.groupBox)
        self.arg2.setGeometry(QtCore.QRect(110, 50, 100, 28))
        self.arg2.setObjectName("arg2")
        self.arg3 = QtGui.QLineEdit(self.groupBox)
        self.arg3.setGeometry(QtCore.QRect(110, 80, 100, 28))
        self.arg3.setObjectName("arg3")
        self.arg4 = QtGui.QLineEdit(self.groupBox)
        self.arg4.setGeometry(QtCore.QRect(110, 110, 100, 28))
        self.arg4.setObjectName("arg4")
        self.arg5 = QtGui.QLineEdit(self.groupBox)
        self.arg5.setGeometry(QtCore.QRect(110, 140, 100, 28))
        self.arg5.setObjectName("arg5")
        self.arg6 = QtGui.QLineEdit(self.groupBox)
        self.arg6.setGeometry(QtCore.QRect(110, 170, 100, 28))
        self.arg6.setObjectName("arg6")
        self.arg7 = QtGui.QLineEdit(self.groupBox)
        self.arg7.setGeometry(QtCore.QRect(110, 200, 100, 28))
        self.arg7.setObjectName("arg7")
        self.arg8 = QtGui.QLineEdit(self.groupBox)
        self.arg8.setGeometry(QtCore.QRect(110, 230, 100, 28))
        self.arg8.setObjectName("arg8")
        self.argst1 = QtGui.QLabel(self.groupBox)
        self.argst1.setGeometry(QtCore.QRect(0, 30, 101, 20))
        self.argst1.setObjectName("argst1")
        self.argst2 = QtGui.QLabel(self.groupBox)
        self.argst2.setGeometry(QtCore.QRect(0, 60, 101, 20))
        self.argst2.setObjectName("argst2")
        self.argst3 = QtGui.QLabel(self.groupBox)
        self.argst3.setGeometry(QtCore.QRect(0, 90, 101, 20))
        self.argst3.setObjectName("argst3")
        self.argst4 = QtGui.QLabel(self.groupBox)
        self.argst4.setGeometry(QtCore.QRect(0, 120, 101, 20))
        self.argst4.setObjectName("argst4")
        self.argst5 = QtGui.QLabel(self.groupBox)
        self.argst5.setGeometry(QtCore.QRect(0, 150, 101, 20))
        self.argst5.setObjectName("argst5")
        self.argst6 = QtGui.QLabel(self.groupBox)
        self.argst6.setGeometry(QtCore.QRect(0, 180, 101, 20))
        self.argst6.setObjectName("argst6")
        self.argst7 = QtGui.QLabel(self.groupBox)
        self.argst7.setGeometry(QtCore.QRect(0, 210, 101, 20))
        self.argst7.setObjectName("argst7")
        self.argst8 = QtGui.QLabel(self.groupBox)
        self.argst8.setGeometry(QtCore.QRect(0, 240, 101, 20))
        self.argst8.setObjectName("argst8")
        self.retval = QtGui.QLineEdit(self.centralwidget)
        self.retval.setGeometry(QtCore.QRect(450, 60, 100, 28))
        self.retval.setObjectName("retval")
        self.label = QtGui.QLabel(self.centralwidget)
        self.label.setGeometry(QtCore.QRect(450, 40, 91, 17))
        self.label.setObjectName("label")
        self.btExec = QtGui.QPushButton(self.centralwidget)
        self.btExec.setGeometry(QtCore.QRect(468, 110, 80, 32))
        self.btExec.setObjectName("btExec")
        self.btClose = QtGui.QPushButton(self.centralwidget)
        self.btClose.setGeometry(QtCore.QRect(470, 170, 80, 32))
        self.btClose.setObjectName("btClose")
        visframe.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(visframe)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 558, 25))
        self.menubar.setObjectName("menubar")
        visframe.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(visframe)
        self.statusbar.setObjectName("statusbar")
        visframe.setStatusBar(self.statusbar)

        self.retranslateUi(visframe)
        QtCore.QMetaObject.connectSlotsByName(visframe)

    def retranslateUi(self, visframe):
        visframe.setWindowTitle(QtGui.QApplication.translate("visframe", "MainWindow", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("visframe", "Arguments", None, QtGui.QApplication.UnicodeUTF8))
        self.argst1.setText(QtGui.QApplication.translate("visframe", "Argument", None, QtGui.QApplication.UnicodeUTF8))
        self.argst2.setText(QtGui.QApplication.translate("visframe", "Argument", None, QtGui.QApplication.UnicodeUTF8))
        self.argst3.setText(QtGui.QApplication.translate("visframe", "Argument", None, QtGui.QApplication.UnicodeUTF8))
        self.argst4.setText(QtGui.QApplication.translate("visframe", "Argument", None, QtGui.QApplication.UnicodeUTF8))
        self.argst5.setText(QtGui.QApplication.translate("visframe", "Argument", None, QtGui.QApplication.UnicodeUTF8))
        self.argst6.setText(QtGui.QApplication.translate("visframe", "Argument", None, QtGui.QApplication.UnicodeUTF8))
        self.argst7.setText(QtGui.QApplication.translate("visframe", "Argument", None, QtGui.QApplication.UnicodeUTF8))
        self.argst8.setText(QtGui.QApplication.translate("visframe", "Argument", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("visframe", "Return Label", None, QtGui.QApplication.UnicodeUTF8))
        self.btExec.setText(QtGui.QApplication.translate("visframe", "Execute", None, QtGui.QApplication.UnicodeUTF8))
        self.btClose.setText(QtGui.QApplication.translate("visframe", "Close", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'SequencerQ_LDR_Serv.ui'
#
# Created: Mon Jan 15 19:09:36 2018
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DialogServerConnect(object):
    def setupUi(self, DialogServerConnect):
        DialogServerConnect.setObjectName("DialogServerConnect")
        DialogServerConnect.resize(363, 325)
        self.groupBox = QtGui.QGroupBox(DialogServerConnect)
        self.groupBox.setGeometry(QtCore.QRect(20, 0, 331, 181))
        self.groupBox.setObjectName("groupBox")
        self.label = QtGui.QLabel(self.groupBox)
        self.label.setGeometry(QtCore.QRect(20, 120, 91, 17))
        self.label.setObjectName("label")
        self.txServerAddress = QtGui.QLineEdit(self.groupBox)
        self.txServerAddress.setGeometry(QtCore.QRect(130, 120, 181, 27))
        self.txServerAddress.setObjectName("txServerAddress")
        self.label_2 = QtGui.QLabel(self.groupBox)
        self.label_2.setGeometry(QtCore.QRect(20, 140, 68, 17))
        self.label_2.setObjectName("label_2")
        self.txPortNo = QtGui.QLineEdit(self.groupBox)
        self.txPortNo.setGeometry(QtCore.QRect(130, 150, 113, 27))
        self.txPortNo.setObjectName("txPortNo")
        self.label_3 = QtGui.QLabel(self.groupBox)
        self.label_3.setGeometry(QtCore.QRect(20, 20, 101, 17))
        self.label_3.setObjectName("label_3")
        self.txtRunNo = QtGui.QLabel(self.groupBox)
        self.txtRunNo.setGeometry(QtCore.QRect(170, 20, 111, 17))
        self.txtRunNo.setObjectName("txtRunNo")
        self.label_5 = QtGui.QLabel(self.groupBox)
        self.label_5.setGeometry(QtCore.QRect(20, 40, 141, 17))
        self.label_5.setObjectName("label_5")
        self.txtDetectModules = QtGui.QLabel(self.groupBox)
        self.txtDetectModules.setGeometry(QtCore.QRect(50, 60, 281, 51))
        self.txtDetectModules.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.txtDetectModules.setObjectName("txtDetectModules")
        self.btConnectToServer = QtGui.QPushButton(DialogServerConnect)
        self.btConnectToServer.setGeometry(QtCore.QRect(20, 190, 131, 51))
        self.btConnectToServer.setObjectName("btConnectToServer")
        self.txtMessage = QtGui.QLabel(DialogServerConnect)
        self.txtMessage.setGeometry(QtCore.QRect(180, 190, 161, 101))
        self.txtMessage.setObjectName("txtMessage")
        self.btClose = QtGui.QPushButton(DialogServerConnect)
        self.btClose.setGeometry(QtCore.QRect(270, 290, 71, 27))
        self.btClose.setObjectName("btClose")
        self.btDisconnect = QtGui.QPushButton(DialogServerConnect)
        self.btDisconnect.setGeometry(QtCore.QRect(40, 290, 99, 27))
        self.btDisconnect.setObjectName("btDisconnect")

        self.retranslateUi(DialogServerConnect)
        QtCore.QMetaObject.connectSlotsByName(DialogServerConnect)

    def retranslateUi(self, DialogServerConnect):
        DialogServerConnect.setWindowTitle(QtGui.QApplication.translate("DialogServerConnect", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("DialogServerConnect", "Server Information", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("DialogServerConnect", "IPAddress : ", None, QtGui.QApplication.UnicodeUTF8))
        self.txServerAddress.setText(QtGui.QApplication.translate("DialogServerConnect", "localhost", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("DialogServerConnect", "Port No :", None, QtGui.QApplication.UnicodeUTF8))
        self.txPortNo.setText(QtGui.QApplication.translate("DialogServerConnect", "2223", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("DialogServerConnect", "Run Number : ", None, QtGui.QApplication.UnicodeUTF8))
        self.txtRunNo.setText(QtGui.QApplication.translate("DialogServerConnect", "XXX000000", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("DialogServerConnect", "Detector Modules :", None, QtGui.QApplication.UnicodeUTF8))
        self.txtDetectModules.setText(QtGui.QApplication.translate("DialogServerConnect", "None", None, QtGui.QApplication.UnicodeUTF8))
        self.btConnectToServer.setText(QtGui.QApplication.translate("DialogServerConnect", "Connect", None, QtGui.QApplication.UnicodeUTF8))
        self.txtMessage.setText(QtGui.QApplication.translate("DialogServerConnect", "None", None, QtGui.QApplication.UnicodeUTF8))
        self.btClose.setText(QtGui.QApplication.translate("DialogServerConnect", "Close", None, QtGui.QApplication.UnicodeUTF8))
        self.btDisconnect.setText(QtGui.QApplication.translate("DialogServerConnect", "Disconnect", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'VisContQ_Main.ui'
#
# Created: Fri Jun 12 18:58:24 2020
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!

from PySide import QtCore, QtGui

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(574, 683)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.btApply = QtGui.QPushButton(self.centralwidget)
        self.btApply.setGeometry(QtCore.QRect(220, 10, 211, 31))
        self.btApply.setObjectName("btApply")
        self.btOpperate = QtGui.QPushButton(self.centralwidget)
        self.btOpperate.setGeometry(QtCore.QRect(460, 10, 99, 27))
        self.btOpperate.setObjectName("btOpperate")
        self.tabWidget = QtGui.QTabWidget(self.centralwidget)
        self.tabWidget.setGeometry(QtCore.QRect(0, 50, 571, 586))
        self.tabWidget.setObjectName("tabWidget")
        self.splash_label = QtGui.QLabel(self.centralwidget)
        self.splash_label.setGeometry(QtCore.QRect(5, 5, 200, 40))
        self.splash_label.setText("")
        self.splash_label.setObjectName("splash_label")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 574, 25))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtGui.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.menu_load = QtGui.QAction(MainWindow)
        self.menu_load.setObjectName("menu_load")
        self.menu_legacy = QtGui.QAction(MainWindow)
        self.menu_legacy.setObjectName("menu_legacy")
        self.actionSave_as = QtGui.QAction(MainWindow)
        self.actionSave_as.setObjectName("actionSave_as")
        self.menu_load_qxqyqz_text = QtGui.QAction(MainWindow)
        self.menu_load_qxqyqz_text.setObjectName("menu_load_qxqyqz_text")
        self.menu_setting = QtGui.QAction(MainWindow)
        self.menu_setting.setObjectName("menu_setting")
        self.menu_exit = QtGui.QAction(MainWindow)
        self.menu_exit.setObjectName("menu_exit")
        self.menuFile.addAction(self.menu_load)
        self.menuFile.addAction(self.menu_legacy)
        self.menuFile.addAction(self.actionSave_as)
        self.menuFile.addAction(self.menu_load_qxqyqz_text)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.menu_setting)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.menu_exit)
        self.menubar.addAction(self.menuFile.menuAction())

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(-1)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "MainWindow", None, QtGui.QApplication.UnicodeUTF8))
        self.btApply.setText(QtGui.QApplication.translate("MainWindow", "Apply params to other Tabs", None, QtGui.QApplication.UnicodeUTF8))
        self.btOpperate.setText(QtGui.QApplication.translate("MainWindow", "CalcBar", None, QtGui.QApplication.UnicodeUTF8))
        self.menuFile.setTitle(QtGui.QApplication.translate("MainWindow", "File...", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_load.setText(QtGui.QApplication.translate("MainWindow", "Load", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_legacy.setText(QtGui.QApplication.translate("MainWindow", "Load Legacy...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave_as.setText(QtGui.QApplication.translate("MainWindow", "Save as ...", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_load_qxqyqz_text.setText(QtGui.QApplication.translate("MainWindow", "Load QxQyQz..", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_setting.setText(QtGui.QApplication.translate("MainWindow", "Setting ...", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_exit.setText(QtGui.QApplication.translate("MainWindow", "Exit", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'VisContQ_DataOperationDialog.ui'
#
# Created: Fri Jun 12 18:58:24 2020
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DataOperationDialog(object):
    def setupUi(self, DataOperationDialog):
        DataOperationDialog.setObjectName("DataOperationDialog")
        DataOperationDialog.resize(560, 160)
        self.groupBox = QtGui.QGroupBox(DataOperationDialog)
        self.groupBox.setGeometry(QtCore.QRect(20, 10, 521, 101))
        self.groupBox.setObjectName("groupBox")
        self.ckPr = QtGui.QCheckBox(self.groupBox)
        self.ckPr.setGeometry(QtCore.QRect(10, 30, 201, 22))
        self.ckPr.setObjectName("ckPr")
        self.cb0 = QtGui.QComboBox(self.groupBox)
        self.cb0.setGeometry(QtCore.QRect(10, 60, 40, 26))
        self.cb0.setObjectName("cb0")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.cb0.addItem("")
        self.stEQ = QtGui.QLabel(self.groupBox)
        self.stEQ.setGeometry(QtCore.QRect(60, 60, 21, 26))
        self.stEQ.setObjectName("stEQ")
        self.m1 = QtGui.QLineEdit(self.groupBox)
        self.m1.setGeometry(QtCore.QRect(80, 60, 50, 26))
        self.m1.setObjectName("m1")
        self.asta1 = QtGui.QLabel(self.groupBox)
        self.asta1.setGeometry(QtCore.QRect(140, 60, 21, 26))
        self.asta1.setObjectName("asta1")
        self.cb1 = QtGui.QComboBox(self.groupBox)
        self.cb1.setGeometry(QtCore.QRect(160, 60, 40, 26))
        self.cb1.setObjectName("cb1")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cb1.addItem("")
        self.cbOP = QtGui.QComboBox(self.groupBox)
        self.cbOP.setGeometry(QtCore.QRect(220, 60, 40, 26))
        self.cbOP.setObjectName("cbOP")
        self.cbOP.addItem("")
        self.cbOP.addItem("")
        self.cbOP.addItem("")
        self.cbOP.setItemText(2, "")
        self.asta2 = QtGui.QLabel(self.groupBox)
        self.asta2.setGeometry(QtCore.QRect(340, 60, 21, 26))
        self.asta2.setObjectName("asta2")
        self.cb2 = QtGui.QComboBox(self.groupBox)
        self.cb2.setGeometry(QtCore.QRect(360, 60, 40, 26))
        self.cb2.setObjectName("cb2")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.cb2.addItem("")
        self.m2 = QtGui.QLineEdit(self.groupBox)
        self.m2.setGeometry(QtCore.QRect(280, 60, 50, 26))
        self.m2.setObjectName("m2")
        self.btCalc = QtGui.QPushButton(self.groupBox)
        self.btCalc.setGeometry(QtCore.QRect(420, 60, 91, 27))
        self.btCalc.setObjectName("btCalc")
        self.btClose = QtGui.QPushButton(DataOperationDialog)
        self.btClose.setGeometry(QtCore.QRect(210, 120, 99, 27))
        self.btClose.setObjectName("btClose")

        self.retranslateUi(DataOperationDialog)
        QtCore.QMetaObject.connectSlotsByName(DataOperationDialog)
        DataOperationDialog.setTabOrder(self.ckPr, self.cb0)
        DataOperationDialog.setTabOrder(self.cb0, self.m1)
        DataOperationDialog.setTabOrder(self.m1, self.cb1)
        DataOperationDialog.setTabOrder(self.cb1, self.cbOP)
        DataOperationDialog.setTabOrder(self.cbOP, self.m2)
        DataOperationDialog.setTabOrder(self.m2, self.cb2)
        DataOperationDialog.setTabOrder(self.cb2, self.btCalc)
        DataOperationDialog.setTabOrder(self.btCalc, self.btClose)

    def retranslateUi(self, DataOperationDialog):
        DataOperationDialog.setWindowTitle(QtGui.QApplication.translate("DataOperationDialog", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("DataOperationDialog", "GroupBox", None, QtGui.QApplication.UnicodeUTF8))
        self.ckPr.setText(QtGui.QApplication.translate("DataOperationDialog", "Calculate Slicing Dta", None, QtGui.QApplication.UnicodeUTF8))
        self.cb0.setItemText(0, QtGui.QApplication.translate("DataOperationDialog", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.cb0.setItemText(1, QtGui.QApplication.translate("DataOperationDialog", "B", None, QtGui.QApplication.UnicodeUTF8))
        self.cb0.setItemText(2, QtGui.QApplication.translate("DataOperationDialog", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.cb0.setItemText(3, QtGui.QApplication.translate("DataOperationDialog", "D", None, QtGui.QApplication.UnicodeUTF8))
        self.cb0.setItemText(4, QtGui.QApplication.translate("DataOperationDialog", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.cb0.setItemText(5, QtGui.QApplication.translate("DataOperationDialog", "F", None, QtGui.QApplication.UnicodeUTF8))
        self.cb0.setItemText(6, QtGui.QApplication.translate("DataOperationDialog", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.cb0.setItemText(7, QtGui.QApplication.translate("DataOperationDialog", "H", None, QtGui.QApplication.UnicodeUTF8))
        self.cb0.setItemText(8, QtGui.QApplication.translate("DataOperationDialog", "I", None, QtGui.QApplication.UnicodeUTF8))
        self.cb0.setItemText(9, QtGui.QApplication.translate("DataOperationDialog", "J", None, QtGui.QApplication.UnicodeUTF8))
        self.stEQ.setText(QtGui.QApplication.translate("DataOperationDialog", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.asta1.setText(QtGui.QApplication.translate("DataOperationDialog", "*", None, QtGui.QApplication.UnicodeUTF8))
        self.cb1.setItemText(0, QtGui.QApplication.translate("DataOperationDialog", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.cb1.setItemText(1, QtGui.QApplication.translate("DataOperationDialog", "B", None, QtGui.QApplication.UnicodeUTF8))
        self.cb1.setItemText(2, QtGui.QApplication.translate("DataOperationDialog", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.cb1.setItemText(3, QtGui.QApplication.translate("DataOperationDialog", "D", None, QtGui.QApplication.UnicodeUTF8))
        self.cb1.setItemText(4, QtGui.QApplication.translate("DataOperationDialog", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.cb1.setItemText(5, QtGui.QApplication.translate("DataOperationDialog", "F", None, QtGui.QApplication.UnicodeUTF8))
        self.cb1.setItemText(6, QtGui.QApplication.translate("DataOperationDialog", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.cb1.setItemText(7, QtGui.QApplication.translate("DataOperationDialog", "H", None, QtGui.QApplication.UnicodeUTF8))
        self.cb1.setItemText(8, QtGui.QApplication.translate("DataOperationDialog", "I", None, QtGui.QApplication.UnicodeUTF8))
        self.cb1.setItemText(9, QtGui.QApplication.translate("DataOperationDialog", "J", None, QtGui.QApplication.UnicodeUTF8))
        self.cbOP.setItemText(0, QtGui.QApplication.translate("DataOperationDialog", "-", None, QtGui.QApplication.UnicodeUTF8))
        self.cbOP.setItemText(1, QtGui.QApplication.translate("DataOperationDialog", "+", None, QtGui.QApplication.UnicodeUTF8))
        self.asta2.setText(QtGui.QApplication.translate("DataOperationDialog", "*", None, QtGui.QApplication.UnicodeUTF8))
        self.cb2.setItemText(0, QtGui.QApplication.translate("DataOperationDialog", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.cb2.setItemText(1, QtGui.QApplication.translate("DataOperationDialog", "B", None, QtGui.QApplication.UnicodeUTF8))
        self.cb2.setItemText(2, QtGui.QApplication.translate("DataOperationDialog", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.cb2.setItemText(3, QtGui.QApplication.translate("DataOperationDialog", "D", None, QtGui.QApplication.UnicodeUTF8))
        self.cb2.setItemText(4, QtGui.QApplication.translate("DataOperationDialog", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.cb2.setItemText(5, QtGui.QApplication.translate("DataOperationDialog", "F", None, QtGui.QApplication.UnicodeUTF8))
        self.cb2.setItemText(6, QtGui.QApplication.translate("DataOperationDialog", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.cb2.setItemText(7, QtGui.QApplication.translate("DataOperationDialog", "H", None, QtGui.QApplication.UnicodeUTF8))
        self.cb2.setItemText(8, QtGui.QApplication.translate("DataOperationDialog", "I", None, QtGui.QApplication.UnicodeUTF8))
        self.cb2.setItemText(9, QtGui.QApplication.translate("DataOperationDialog", "J", None, QtGui.QApplication.UnicodeUTF8))
        self.btCalc.setText(QtGui.QApplication.translate("DataOperationDialog", "Calculate", None, QtGui.QApplication.UnicodeUTF8))
        self.btClose.setText(QtGui.QApplication.translate("DataOperationDialog", "Close", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'VisContQ_SettingDialog.ui'
#
# Created: Fri Jun 12 18:58:24 2020
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_SettingDialog(object):
    def setupUi(self, SettingDialog):
        SettingDialog.setObjectName("SettingDialog")
        SettingDialog.resize(400, 85)
        self.groupBox = QtGui.QGroupBox(SettingDialog)
        self.groupBox.setGeometry(QtCore.QRect(0, 0, 371, 80))
        self.groupBox.setObjectName("groupBox")
        self.ckSliceAverageMode = QtGui.QCheckBox(self.groupBox)
        self.ckSliceAverageMode.setGeometry(QtCore.QRect(20, 30, 371, 22))
        self.ckSliceAverageMode.setObjectName("ckSliceAverageMode")

        self.retranslateUi(SettingDialog)
        QtCore.QMetaObject.connectSlotsByName(SettingDialog)

    def retranslateUi(self, SettingDialog):
        SettingDialog.setWindowTitle(QtGui.QApplication.translate("SettingDialog", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("SettingDialog", "Slice", None, QtGui.QApplication.UnicodeUTF8))
        self.ckSliceAverageMode.setText(QtGui.QApplication.translate("SettingDialog", "Average Mode    On : Average  / Off : Sum", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-
"""

"""
import vis.DetectMap as dpc
import time
import vis.MPlot as mp
import vis.M2Plot as mp2

# 予約語の定義
ret = None 
vp1 = None
vp2 = None
vc = None
vc2 = None
vc3 = None
ec = None
earray = None
DAT = None
ECM = None
vcm = None
        
###################################################                            
def DetectMap(matrix=DAT):
        """
        Display Detector Map
        @param  matrix [Def:DAT] ElementContainerMatrix Object 
        @retval None
        """ 
	## Check Size of ElementContainers (pixels) in a ElementContainer( PSD )
	v_size = 0.0
	for i in range( matrix.PutSize() ):
		if v_size==0.0:
			v_size = matrix(i).PutSize()
		elif v_size!=(matrix(i).PutSize()):
			raise UserWarning,"Data includes several banks which the number of pixels are different"
		
        dpc.MapFrame(None, matrix)    
        

###################################################                         
def MPlot(ec=ec):
        """
        Create 1D Plotter and Draw EC
        @param  ec [Def:EC] ElementContainer
        @param  psd      PSD No.    
        @param  pixel    Pixel No.    
        @retval vp1    Instance of Plotter
        """ 
        # 親プロセス終了時に、プロッタを終了      
	p=mp.MPlot(ec, True)
	
	a_ec = None
	if isinstance( ec, list ):
		a_ec = ec[0]
	else:
		a_ec = ec
	
	h=a_ec.PutHeaderPointer()
	
	if h.CheckKey("XLABEL")==1:
		p.SetXLabel( h.PutString("XLABEL") )
	if h.CheckKey("YLABEL")==1:
		p.SetYLabel( h.PutString("YLABEL") )
	if h.CheckKey("XAxis")==1:
	#	if (h.PutString("XAxis") == "Q"):
	#		p.SetLogX(True)
	#		p.SetXScale(0.03,2)
	#		p.SetLog(True)
	#		p.SetYScale(1e-07,2.0)
	#	elif (h.PutString("XAxis") == "TOF"):
	#		p.SetLog(True)
	#		p.SetYScale(1e-07,2.0)
		p.SetPlotParam(0, ls="-")
	#p.SetMainTitle( title )
        return p
    
###################################################                            
def AddToMPlot(vp1=vp1, ec=ec):
        """
        Add EC to 1D Plotter
        @param  vp1 [Def:vp1] Instance of 1D Plotter
        @param  ec  [Def:EC] ElementContainer
        @retval None
        """ 
        vp1.AddData(ec)  
        
###################################################                         
def M2Plot(matrix=ECM):
        """
        Create 2D Plotter and display 2D Map
        @param  matrix [Def:ECA] ElementContainerArray
        @retval vp2 [Def:vp2] Instance of 2D Plotter
        """ 
        # 親プロセス終了時に、プロッタを終了      
        return mp2.M2Plot(matrix, True)

###################################################
def ChangeMap(vp2=vp2, matrix=ECM):
        """
        Change 2D Map of M2Plot
	@param  vp2   [Def:vp2]  Instance of 2D Plotter
        @param  matrix [Def:DAT] ElementContainerArray
        @retval None
        """ 
        # Map データの変更
        vp2.ChangeMap(matrix)	

           

# 関数名登録ディクショナリ
_functions = {"DetectMap":DetectMap,
              "MPlot":MPlot,
              "AddToMPlot":AddToMPlot,
              "M2Plot":M2Plot,
	      "ChangeMap":ChangeMap,
	      }
         
_functionsOrder = [
	"DetectMap",
	"MPlot",
	"AddToMPlot",
	"M2Plot",
	"ChangeMap",
	]
